# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/ge3.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/ge3.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1emodules/canbus/proto/ge3.proto\x12\rapollo.canbus\"\x9b\x08\n\nPc_bcm_201\x12J\n\x11pc_reverselampreq\x18\x01 \x01(\x0e\x32/.apollo.canbus.Pc_bcm_201.Pc_reverselampreqType\x12\x42\n\rpc_lowbeamreq\x18\x02 \x01(\x0e\x32+.apollo.canbus.Pc_bcm_201.Pc_lowbeamreqType\x12\x44\n\x0epc_highbeamreq\x18\x03 \x01(\x0e\x32,.apollo.canbus.Pc_bcm_201.Pc_highbeamreqType\x12N\n\x13pc_rightturnlampreq\x18\x04 \x01(\x0e\x32\x31.apollo.canbus.Pc_bcm_201.Pc_rightturnlampreqType\x12L\n\x12pc_leftturnlampreq\x18\x05 \x01(\x0e\x32\x30.apollo.canbus.Pc_bcm_201.Pc_leftturnlampreqType\x12<\n\npc_hornreq\x18\x06 \x01(\x0e\x32(.apollo.canbus.Pc_bcm_201.Pc_hornreqType\x12H\n\x10pc_hazardlampreq\x18\x07 \x01(\x0e\x32..apollo.canbus.Pc_bcm_201.Pc_hazardlampreqType\"O\n\x15Pc_reverselampreqType\x12\x1b\n\x17PC_REVERSELAMPREQ_NOREQ\x10\x00\x12\x19\n\x15PC_REVERSELAMPREQ_REQ\x10\x01\"C\n\x11Pc_lowbeamreqType\x12\x17\n\x13PC_LOWBEAMREQ_NOREQ\x10\x00\x12\x15\n\x11PC_LOWBEAMREQ_REQ\x10\x01\"F\n\x12Pc_highbeamreqType\x12\x18\n\x14PC_HIGHBEAMREQ_NOREQ\x10\x00\x12\x16\n\x12PC_HIGHBEAMREQ_REQ\x10\x01\"U\n\x17Pc_rightturnlampreqType\x12\x1d\n\x19PC_RIGHTTURNLAMPREQ_NOREQ\x10\x00\x12\x1b\n\x17PC_RIGHTTURNLAMPREQ_REQ\x10\x01\"R\n\x16Pc_leftturnlampreqType\x12\x1c\n\x18PC_LEFTTURNLAMPREQ_NOREQ\x10\x00\x12\x1a\n\x16PC_LEFTTURNLAMPREQ_REQ\x10\x01\":\n\x0ePc_hornreqType\x12\x14\n\x10PC_HORNREQ_NOREQ\x10\x00\x12\x12\n\x0ePC_HORNREQ_REQ\x10\x01\"L\n\x14Pc_hazardlampreqType\x12\x1a\n\x16PC_HAZARDLAMPREQ_NOREQ\x10\x00\x12\x18\n\x14PC_HAZARDLAMPREQ_REQ\x10\x01\"\xb7\x11\n\rScu_bcs_3_308\x12K\n\x10\x62\x63s_rrwheelspdvd\x18\x01 \x01(\x0e\x32\x31.apollo.canbus.Scu_bcs_3_308.Bcs_rrwheelspdvdType\x12W\n\x16\x62\x63s_rrwheeldirectionvd\x18\x02 \x01(\x0e\x32\x37.apollo.canbus.Scu_bcs_3_308.Bcs_rrwheeldirectionvdType\x12K\n\x10\x62\x63s_rlwheelspdvd\x18\x03 \x01(\x0e\x32\x31.apollo.canbus.Scu_bcs_3_308.Bcs_rlwheelspdvdType\x12W\n\x16\x62\x63s_rlwheeldirectionvd\x18\x04 \x01(\x0e\x32\x37.apollo.canbus.Scu_bcs_3_308.Bcs_rlwheeldirectionvdType\x12K\n\x10\x62\x63s_frwheelspdvd\x18\x05 \x01(\x0e\x32\x31.apollo.canbus.Scu_bcs_3_308.Bcs_frwheelspdvdType\x12W\n\x16\x62\x63s_frwheeldirectionvd\x18\x06 \x01(\x0e\x32\x37.apollo.canbus.Scu_bcs_3_308.Bcs_frwheeldirectionvdType\x12K\n\x10\x62\x63s_flwheelspdvd\x18\x07 \x01(\x0e\x32\x31.apollo.canbus.Scu_bcs_3_308.Bcs_flwheelspdvdType\x12W\n\x16\x62\x63s_flwheeldirectionvd\x18\x08 \x01(\x0e\x32\x37.apollo.canbus.Scu_bcs_3_308.Bcs_flwheeldirectionvdType\x12\x16\n\x0e\x62\x63s_rrwheelspd\x18\t \x01(\x01\x12S\n\x14\x62\x63s_rrwheeldirection\x18\n \x01(\x0e\x32\x35.apollo.canbus.Scu_bcs_3_308.Bcs_rrwheeldirectionType\x12\x16\n\x0e\x62\x63s_rlwheelspd\x18\x0b \x01(\x01\x12S\n\x14\x62\x63s_rlwheeldirection\x18\x0c \x01(\x0e\x32\x35.apollo.canbus.Scu_bcs_3_308.Bcs_rlwheeldirectionType\x12\x16\n\x0e\x62\x63s_frwheelspd\x18\r \x01(\x01\x12S\n\x14\x62\x63s_frwheeldirection\x18\x0e \x01(\x0e\x32\x35.apollo.canbus.Scu_bcs_3_308.Bcs_frwheeldirectionType\x12\x16\n\x0e\x62\x63s_flwheelspd\x18\x0f \x01(\x01\x12S\n\x14\x62\x63s_flwheeldirection\x18\x10 \x01(\x0e\x32\x35.apollo.canbus.Scu_bcs_3_308.Bcs_flwheeldirectionType\"P\n\x14\x42\x63s_rrwheelspdvdType\x12\x1c\n\x18\x42\x43S_RRWHEELSPDVD_INVALID\x10\x00\x12\x1a\n\x16\x42\x43S_RRWHEELSPDVD_VALID\x10\x01\"b\n\x1a\x42\x63s_rrwheeldirectionvdType\x12\"\n\x1e\x42\x43S_RRWHEELDIRECTIONVD_INVALID\x10\x00\x12 \n\x1c\x42\x43S_RRWHEELDIRECTIONVD_VALID\x10\x01\"P\n\x14\x42\x63s_rlwheelspdvdType\x12\x1c\n\x18\x42\x43S_RLWHEELSPDVD_INVALID\x10\x00\x12\x1a\n\x16\x42\x43S_RLWHEELSPDVD_VALID\x10\x01\"b\n\x1a\x42\x63s_rlwheeldirectionvdType\x12\"\n\x1e\x42\x43S_RLWHEELDIRECTIONVD_INVALID\x10\x00\x12 \n\x1c\x42\x43S_RLWHEELDIRECTIONVD_VALID\x10\x01\"P\n\x14\x42\x63s_frwheelspdvdType\x12\x1c\n\x18\x42\x43S_FRWHEELSPDVD_INVALID\x10\x00\x12\x1a\n\x16\x42\x43S_FRWHEELSPDVD_VALID\x10\x01\"b\n\x1a\x42\x63s_frwheeldirectionvdType\x12\"\n\x1e\x42\x43S_FRWHEELDIRECTIONVD_INVALID\x10\x00\x12 \n\x1c\x42\x43S_FRWHEELDIRECTIONVD_VALID\x10\x01\"P\n\x14\x42\x63s_flwheelspdvdType\x12\x1c\n\x18\x42\x43S_FLWHEELSPDVD_INVALID\x10\x00\x12\x1a\n\x16\x42\x43S_FLWHEELSPDVD_VALID\x10\x01\"b\n\x1a\x42\x63s_flwheeldirectionvdType\x12\"\n\x1e\x42\x43S_FLWHEELDIRECTIONVD_INVALID\x10\x00\x12 \n\x1c\x42\x43S_FLWHEELDIRECTIONVD_VALID\x10\x01\"_\n\x18\x42\x63s_rrwheeldirectionType\x12 \n\x1c\x42\x43S_RRWHEELDIRECTION_FORWARD\x10\x00\x12!\n\x1d\x42\x43S_RRWHEELDIRECTION_BACKWARD\x10\x01\"_\n\x18\x42\x63s_rlwheeldirectionType\x12 \n\x1c\x42\x43S_RLWHEELDIRECTION_FORWARD\x10\x00\x12!\n\x1d\x42\x43S_RLWHEELDIRECTION_BACKWARD\x10\x01\"_\n\x18\x42\x63s_frwheeldirectionType\x12 \n\x1c\x42\x43S_FRWHEELDIRECTION_FORWARD\x10\x00\x12!\n\x1d\x42\x43S_FRWHEELDIRECTION_BACKWARD\x10\x01\"_\n\x18\x42\x63s_flwheeldirectionType\x12 \n\x1c\x42\x43S_FLWHEELDIRECTION_FORWARD\x10\x00\x12!\n\x1d\x42\x43S_FLWHEELDIRECTION_BACKWARD\x10\x01\"\xa5\x02\n\nPc_epb_203\x12:\n\tpc_epbreq\x18\x01 \x01(\x0e\x32\'.apollo.canbus.Pc_epb_203.Pc_epbreqType\x12@\n\x0cpc_epbenable\x18\x02 \x01(\x0e\x32*.apollo.canbus.Pc_epb_203.Pc_epbenableType\"R\n\rPc_epbreqType\x12\x15\n\x11PC_EPBREQ_INVALID\x10\x00\x12\x15\n\x11PC_EPBREQ_RELEASE\x10\x01\x12\x13\n\x0fPC_EPBREQ_APPLY\x10\x02\"E\n\x10Pc_epbenableType\x12\x18\n\x14PC_EPBENABLE_DISABLE\x10\x00\x12\x17\n\x13PC_EPBENABLE_ENABLE\x10\x01\"\xba\x01\n\nPc_bcs_202\x12\x14\n\x0cpc_brkpedreq\x18\x01 \x01(\x01\x12\x46\n\x0fpc_brkpedenable\x18\x02 \x01(\x0e\x32-.apollo.canbus.Pc_bcs_202.Pc_brkpedenableType\"N\n\x13Pc_brkpedenableType\x12\x1b\n\x17PC_BRKPEDENABLE_DISABLE\x10\x00\x12\x1a\n\x16PC_BRKPEDENABLE_ENABLE\x10\x01\"\xae\x05\n\nPc_vcu_205\x12\x14\n\x0cpc_accpedreq\x18\x01 \x01(\x01\x12\x46\n\x0fpc_accpedenable\x18\x02 \x01(\x0e\x32-.apollo.canbus.Pc_vcu_205.Pc_accpedenableType\x12\x12\n\npc_torqreq\x18\x03 \x01(\x01\x12\x42\n\rpc_torqenable\x18\x04 \x01(\x0e\x32+.apollo.canbus.Pc_vcu_205.Pc_torqenableType\x12<\n\npc_gearreq\x18\x05 \x01(\x0e\x32(.apollo.canbus.Pc_vcu_205.Pc_gearreqType\x12\x42\n\rpc_gearenable\x18\x06 \x01(\x0e\x32+.apollo.canbus.Pc_vcu_205.Pc_gearenableType\"N\n\x13Pc_accpedenableType\x12\x1b\n\x17PC_ACCPEDENABLE_DISABLE\x10\x00\x12\x1a\n\x16PC_ACCPEDENABLE_ENABLE\x10\x01\"H\n\x11Pc_torqenableType\x12\x19\n\x15PC_TORQENABLE_DISABLE\x10\x00\x12\x18\n\x14PC_TORQENABLE_ENABLE\x10\x01\"\x83\x01\n\x0ePc_gearreqType\x12\x16\n\x12PC_GEARREQ_INVALID\x10\x00\x12\x14\n\x10PC_GEARREQ_DRIVE\x10\x01\x12\x16\n\x12PC_GEARREQ_NEUTRAL\x10\x02\x12\x16\n\x12PC_GEARREQ_REVERSE\x10\x03\x12\x13\n\x0fPC_GEARREQ_PARK\x10\x04\"H\n\x11Pc_gearenableType\x12\x19\n\x15PC_GEARENABLE_DISABLE\x10\x00\x12\x18\n\x14PC_GEARENABLE_ENABLE\x10\x01\"\xcf\x01\n\nPc_eps_204\x12\x16\n\x0epc_steerspdreq\x18\x01 \x01(\x05\x12\x44\n\x0epc_steerenable\x18\x02 \x01(\x0e\x32,.apollo.canbus.Pc_eps_204.Pc_steerenableType\x12\x16\n\x0epc_steerangreq\x18\x03 \x01(\x01\"K\n\x12Pc_steerenableType\x12\x1a\n\x16PC_STEERENABLE_DISABLE\x10\x00\x12\x19\n\x15PC_STEERENABLE_ENABLE\x10\x01\"h\n\rScu_vcu_2_313\x12\x16\n\x0evcu_torqposmax\x18\x01 \x01(\x01\x12\x16\n\x0evcu_torqnegmax\x18\x02 \x01(\x01\x12\x13\n\x0bvcu_torqact\x18\x03 \x01(\x01\x12\x12\n\nvcu_engspd\x18\x04 \x01(\x05\"\xdf\x03\n\tScu_1_301\x12\r\n\x05vin16\x18\x01 \x01(\x05\x12\x41\n\rscu_stopbutst\x18\x02 \x01(\x0e\x32*.apollo.canbus.Scu_1_301.Scu_stopbutstType\x12=\n\x0bscu_drvmode\x18\x03 \x01(\x0e\x32(.apollo.canbus.Scu_1_301.Scu_drvmodeType\x12=\n\x0bscu_faultst\x18\x04 \x01(\x0e\x32(.apollo.canbus.Scu_1_301.Scu_faultstType\"K\n\x11Scu_stopbutstType\x12\x1b\n\x17SCU_STOPBUTST_UNPRESSED\x10\x00\x12\x19\n\x15SCU_STOPBUTST_PRESSED\x10\x01\"s\n\x0fScu_drvmodeType\x12\x17\n\x13SCU_DRVMODE_INVALID\x10\x00\x12\x16\n\x12SCU_DRVMODE_MANUAL\x10\x01\x12\x19\n\x15SCU_DRVMODE_INTERRUPT\x10\x02\x12\x14\n\x10SCU_DRVMODE_AUTO\x10\x03\"@\n\x0fScu_faultstType\x12\x16\n\x12SCU_FAULTST_NORMAL\x10\x00\x12\x15\n\x11SCU_FAULTST_FAULT\x10\x01\"\x83\x01\n\tScu_2_302\x12\r\n\x05vin07\x18\x01 \x01(\x05\x12\r\n\x05vin06\x18\x02 \x01(\x05\x12\r\n\x05vin05\x18\x03 \x01(\x05\x12\r\n\x05vin04\x18\x04 \x01(\x05\x12\r\n\x05vin03\x18\x05 \x01(\x05\x12\r\n\x05vin02\x18\x06 \x01(\x05\x12\r\n\x05vin01\x18\x07 \x01(\x05\x12\r\n\x05vin00\x18\x08 \x01(\x05\"\x83\x01\n\tScu_3_303\x12\r\n\x05vin15\x18\x01 \x01(\x05\x12\r\n\x05vin14\x18\x02 \x01(\x05\x12\r\n\x05vin13\x18\x03 \x01(\x05\x12\r\n\x05vin12\x18\x04 \x01(\x05\x12\r\n\x05vin11\x18\x05 \x01(\x05\x12\r\n\x05vin10\x18\x06 \x01(\x05\x12\r\n\x05vin09\x18\x07 \x01(\x05\x12\r\n\x05vin08\x18\x08 \x01(\x05\"\x90\x0f\n\x0bScu_bcm_304\x12I\n\x10\x62\x63m_vehreversest\x18\x01 \x01(\x0e\x32/.apollo.canbus.Scu_bcm_304.Bcm_vehreversestType\x12O\n\x13\x62\x63m_rightturnlampst\x18\x02 \x01(\x0e\x32\x32.apollo.canbus.Scu_bcm_304.Bcm_rightturnlampstType\x12K\n\x11\x62\x63m_rearfoglampst\x18\x03 \x01(\x0e\x32\x30.apollo.canbus.Scu_bcm_304.Bcm_rearfoglampstType\x12K\n\x11\x62\x63m_parkinglampst\x18\x04 \x01(\x0e\x32\x30.apollo.canbus.Scu_bcm_304.Bcm_parkinglampstType\x12\x43\n\rbcm_lowbeamst\x18\x05 \x01(\x0e\x32,.apollo.canbus.Scu_bcm_304.Bcm_lowbeamstType\x12M\n\x12\x62\x63m_leftturnlampst\x18\x06 \x01(\x0e\x32\x31.apollo.canbus.Scu_bcm_304.Bcm_leftturnlampstType\x12;\n\tbcm_keyst\x18\x07 \x01(\x0e\x32(.apollo.canbus.Scu_bcm_304.Bcm_keystType\x12=\n\nbcm_hornst\x18\x08 \x01(\x0e\x32).apollo.canbus.Scu_bcm_304.Bcm_hornstType\x12\x45\n\x0e\x62\x63m_highbeamst\x18\t \x01(\x0e\x32-.apollo.canbus.Scu_bcm_304.Bcm_highbeamstType\x12I\n\x10\x62\x63m_hazardlampst\x18\n \x01(\x0e\x32/.apollo.canbus.Scu_bcm_304.Bcm_hazardlampstType\x12M\n\x12\x62\x63m_frontfoglampst\x18\x0b \x01(\x0e\x32\x31.apollo.canbus.Scu_bcm_304.Bcm_frontfoglampstType\x12U\n\x16\x62\x63m_brakelightswitchst\x18\x0c \x01(\x0e\x32\x35.apollo.canbus.Scu_bcm_304.Bcm_brakelightswitchstType\"Q\n\x14\x42\x63m_vehreversestType\x12\x1b\n\x17\x42\x43M_VEHREVERSEST_NORMAL\x10\x00\x12\x1c\n\x18\x42\x43M_VEHREVERSEST_REVERSE\x10\x01\"[\n\x17\x42\x63m_rightturnlampstType\x12 \n\x1c\x42\x43M_RIGHTTURNLAMPST_INACTIVE\x10\x00\x12\x1e\n\x1a\x42\x43M_RIGHTTURNLAMPST_ACTIVE\x10\x01\"U\n\x15\x42\x63m_rearfoglampstType\x12\x1e\n\x1a\x42\x43M_REARFOGLAMPST_INACTIVE\x10\x00\x12\x1c\n\x18\x42\x43M_REARFOGLAMPST_ACTIVE\x10\x01\"U\n\x15\x42\x63m_parkinglampstType\x12\x1e\n\x1a\x42\x43M_PARKINGLAMPST_INACTIVE\x10\x00\x12\x1c\n\x18\x42\x43M_PARKINGLAMPST_ACTIVE\x10\x01\"I\n\x11\x42\x63m_lowbeamstType\x12\x1a\n\x16\x42\x43M_LOWBEAMST_INACTIVE\x10\x00\x12\x18\n\x14\x42\x43M_LOWBEAMST_ACTIVE\x10\x01\"X\n\x16\x42\x63m_leftturnlampstType\x12\x1f\n\x1b\x42\x43M_LEFTTURNLAMPST_INACTIVE\x10\x00\x12\x1d\n\x19\x42\x43M_LEFTTURNLAMPST_ACTIVE\x10\x01\"\\\n\rBcm_keystType\x12\x11\n\rBCM_KEYST_OFF\x10\x00\x12\x11\n\rBCM_KEYST_ACC\x10\x01\x12\x10\n\x0c\x42\x43M_KEYST_ON\x10\x02\x12\x13\n\x0f\x42\x43M_KEYST_CRANK\x10\x03\"@\n\x0e\x42\x63m_hornstType\x12\x17\n\x13\x42\x43M_HORNST_INACTIVE\x10\x00\x12\x15\n\x11\x42\x43M_HORNST_ACTIVE\x10\x01\"L\n\x12\x42\x63m_highbeamstType\x12\x1b\n\x17\x42\x43M_HIGHBEAMST_INACTIVE\x10\x00\x12\x19\n\x15\x42\x43M_HIGHBEAMST_ACTIVE\x10\x01\"R\n\x14\x42\x63m_hazardlampstType\x12\x1d\n\x19\x42\x43M_HAZARDLAMPST_INACTIVE\x10\x00\x12\x1b\n\x17\x42\x43M_HAZARDLAMPST_ACTIVE\x10\x01\"X\n\x16\x42\x63m_frontfoglampstType\x12\x1f\n\x1b\x42\x43M_FRONTFOGLAMPST_INACTIVE\x10\x00\x12\x1d\n\x19\x42\x43M_FRONTFOGLAMPST_ACTIVE\x10\x01\"d\n\x1a\x42\x63m_brakelightswitchstType\x12#\n\x1f\x42\x43M_BRAKELIGHTSWITCHST_INACTIVE\x10\x00\x12!\n\x1d\x42\x43M_BRAKELIGHTSWITCHST_ACTIVE\x10\x01\"\xf8\x0b\n\rScu_bcs_1_306\x12K\n\x10\x62\x63s_aebavailable\x18\x01 \x01(\x0e\x32\x31.apollo.canbus.Scu_bcs_1_306.Bcs_aebavailableType\x12K\n\x10\x62\x63s_cddavailable\x18\x02 \x01(\x0e\x32\x31.apollo.canbus.Scu_bcs_1_306.Bcs_cddavailableType\x12\x15\n\rbcs_brkpedact\x18\x03 \x01(\x01\x12?\n\nbcs_intidx\x18\x04 \x01(\x0e\x32+.apollo.canbus.Scu_bcs_1_306.Bcs_intidxType\x12G\n\x0e\x62\x63s_vdcfaultst\x18\x05 \x01(\x0e\x32/.apollo.canbus.Scu_bcs_1_306.Bcs_vdcfaultstType\x12I\n\x0f\x62\x63s_vdcactivest\x18\x06 \x01(\x0e\x32\x30.apollo.canbus.Scu_bcs_1_306.Bcs_vdcactivestType\x12G\n\x0e\x62\x63s_absfaultst\x18\x07 \x01(\x0e\x32/.apollo.canbus.Scu_bcs_1_306.Bcs_absfaultstType\x12I\n\x0f\x62\x63s_absactivest\x18\x08 \x01(\x0e\x32\x30.apollo.canbus.Scu_bcs_1_306.Bcs_absactivestType\x12\x41\n\x0b\x62\x63s_faultst\x18\t \x01(\x0e\x32,.apollo.canbus.Scu_bcs_1_306.Bcs_faultstType\x12\x41\n\x0b\x62\x63s_drvmode\x18\n \x01(\x0e\x32,.apollo.canbus.Scu_bcs_1_306.Bcs_drvmodeType\"X\n\x14\x42\x63s_aebavailableType\x12 \n\x1c\x42\x43S_AEBAVAILABLE_UNAVAILABLE\x10\x00\x12\x1e\n\x1a\x42\x43S_AEBAVAILABLE_AVAILABLE\x10\x01\"X\n\x14\x42\x63s_cddavailableType\x12 \n\x1c\x42\x43S_CDDAVAILABLE_UNAVAILABLE\x10\x00\x12\x1e\n\x1a\x42\x43S_CDDAVAILABLE_AVAILABLE\x10\x01\"\xa3\x01\n\x0e\x42\x63s_intidxType\x12\x14\n\x10\x42\x43S_INTIDX_NOINT\x10\x00\x12\x17\n\x13\x42\x43S_INTIDX_OVERFLOW\x10\x01\x12\x16\n\x12\x42\x43S_INTIDX_TIMEOUT\x10\x02\x12\x18\n\x14\x42\x43S_INTIDX_ACCPEDINT\x10\x03\x12\x18\n\x14\x42\x43S_INTIDX_BRKPEDINT\x10\x04\x12\x16\n\x12\x42\x43S_INTIDX_GEARINT\x10\x05\"I\n\x12\x42\x63s_vdcfaultstType\x12\x19\n\x15\x42\x43S_VDCFAULTST_NORMAL\x10\x00\x12\x18\n\x14\x42\x43S_VDCFAULTST_FAULT\x10\x01\"O\n\x13\x42\x63s_vdcactivestType\x12\x1c\n\x18\x42\x43S_VDCACTIVEST_INACTIVE\x10\x00\x12\x1a\n\x16\x42\x43S_VDCACTIVEST_ACTIVE\x10\x01\"I\n\x12\x42\x63s_absfaultstType\x12\x19\n\x15\x42\x43S_ABSFAULTST_NORMAL\x10\x00\x12\x18\n\x14\x42\x43S_ABSFAULTST_FAULT\x10\x01\"O\n\x13\x42\x63s_absactivestType\x12\x1c\n\x18\x42\x43S_ABSACTIVEST_INACTIVE\x10\x00\x12\x1a\n\x16\x42\x43S_ABSACTIVEST_ACTIVE\x10\x01\"@\n\x0f\x42\x63s_faultstType\x12\x16\n\x12\x42\x43S_FAULTST_NORMAL\x10\x00\x12\x15\n\x11\x42\x43S_FAULTST_FAULT\x10\x01\"s\n\x0f\x42\x63s_drvmodeType\x12\x17\n\x13\x42\x43S_DRVMODE_INVALID\x10\x00\x12\x16\n\x12\x42\x43S_DRVMODE_MANUAL\x10\x01\x12\x19\n\x15\x42\x43S_DRVMODE_INTERRUPT\x10\x02\x12\x14\n\x10\x42\x43S_DRVMODE_AUTO\x10\x03\"\xf6\x01\n\rScu_bcs_2_307\x12\x43\n\x0c\x62\x63s_vehspdvd\x18\x01 \x01(\x0e\x32-.apollo.canbus.Scu_bcs_2_307.Bcs_vehspdvdType\x12\x13\n\x0b\x62\x63s_yawrate\x18\x02 \x01(\x01\x12\x12\n\nbcs_vehspd\x18\x03 \x01(\x01\x12\x18\n\x10\x62\x63s_vehlongaccel\x18\x04 \x01(\x01\x12\x17\n\x0f\x62\x63s_vehlataccel\x18\x05 \x01(\x01\"D\n\x10\x42\x63s_vehspdvdType\x12\x18\n\x14\x42\x43S_VEHSPDVD_INVALID\x10\x00\x12\x16\n\x12\x42\x43S_VEHSPDVD_VALID\x10\x01\"\xbc\x05\n\x0bScu_epb_310\x12=\n\nepb_intidx\x18\x01 \x01(\x0e\x32).apollo.canbus.Scu_epb_310.Epb_intidxType\x12?\n\x0b\x65pb_drvmode\x18\x02 \x01(\x0e\x32*.apollo.canbus.Scu_epb_310.Epb_drvmodeType\x12;\n\tepb_sysst\x18\x03 \x01(\x0e\x32(.apollo.canbus.Scu_epb_310.Epb_sysstType\x12?\n\x0b\x65pb_faultst\x18\x04 \x01(\x0e\x32*.apollo.canbus.Scu_epb_310.Epb_faultstType\"W\n\x0e\x45pb_intidxType\x12\x14\n\x10\x45PB_INTIDX_NOINT\x10\x00\x12\x17\n\x13\x45PB_INTIDX_OVERFLOW\x10\x01\x12\x16\n\x12\x45PB_INTIDX_TIMEOUT\x10\x02\"s\n\x0f\x45pb_drvmodeType\x12\x17\n\x13\x45PB_DRVMODE_INVALID\x10\x00\x12\x16\n\x12\x45PB_DRVMODE_MANUAL\x10\x01\x12\x19\n\x15\x45PB_DRVMODE_INTERRUPT\x10\x02\x12\x14\n\x10\x45PB_DRVMODE_AUTO\x10\x03\"\x9e\x01\n\rEpb_sysstType\x12\x16\n\x12\x45PB_SYSST_RELEASED\x10\x00\x12\x15\n\x11\x45PB_SYSST_APPLIED\x10\x01\x12\x17\n\x13\x45PB_SYSST_RELEASING\x10\x02\x12\x13\n\x0f\x45PB_SYSST_FAULT\x10\x03\x12\x16\n\x12\x45PB_SYSST_APPLYING\x10\x04\x12\x18\n\x14\x45PB_SYSST_DISENGAGED\x10\x05\"@\n\x0f\x45pb_faultstType\x12\x16\n\x12\x45PB_FAULTST_NORMAL\x10\x00\x12\x15\n\x11\x45PB_FAULTST_FAULT\x10\x01\"\xd9\x10\n\rScu_vcu_1_312\x12I\n\x0fvcu_elcsysfault\x18\x01 \x01(\x0e\x32\x30.apollo.canbus.Scu_vcu_1_312.Vcu_elcsysfaultType\x12\x43\n\x0cvcu_brkpedst\x18\x02 \x01(\x0e\x32-.apollo.canbus.Scu_vcu_1_312.Vcu_brkpedstType\x12?\n\nvcu_intidx\x18\x03 \x01(\x0e\x32+.apollo.canbus.Scu_vcu_1_312.Vcu_intidxType\x12G\n\x0evcu_gearintidx\x18\x04 \x01(\x0e\x32/.apollo.canbus.Scu_vcu_1_312.Vcu_gearintidxType\x12I\n\x0fvcu_geardrvmode\x18\x05 \x01(\x0e\x32\x30.apollo.canbus.Scu_vcu_1_312.Vcu_geardrvmodeType\x12\x15\n\rvcu_accpedact\x18\x06 \x01(\x01\x12\x15\n\rvcu_brkpedpst\x18\x07 \x01(\x01\x12\x12\n\nvcu_vehrng\x18\x08 \x01(\x05\x12\x15\n\rvcu_accpedpst\x18\t \x01(\x01\x12\x43\n\x0cvcu_vehrdyst\x18\n \x01(\x0e\x32-.apollo.canbus.Scu_vcu_1_312.Vcu_vehrdystType\x12\x41\n\x0bvcu_faultst\x18\x0b \x01(\x0e\x32,.apollo.canbus.Scu_vcu_1_312.Vcu_faultstType\x12\x41\n\x0bvcu_drvmode\x18\x0c \x01(\x0e\x32,.apollo.canbus.Scu_vcu_1_312.Vcu_drvmodeType\x12\x41\n\x0bvcu_gearpst\x18\r \x01(\x0e\x32,.apollo.canbus.Scu_vcu_1_312.Vcu_gearpstType\x12I\n\x0fvcu_gearfaultst\x18\x0e \x01(\x0e\x32\x30.apollo.canbus.Scu_vcu_1_312.Vcu_gearfaultstType\x12\x41\n\x0bvcu_gearact\x18\x0f \x01(\x0e\x32,.apollo.canbus.Scu_vcu_1_312.Vcu_gearactType\"L\n\x13Vcu_elcsysfaultType\x12\x1a\n\x16VCU_ELCSYSFAULT_NORMAL\x10\x00\x12\x19\n\x15VCU_ELCSYSFAULT_FAULT\x10\x01\"H\n\x10Vcu_brkpedstType\x12\x1a\n\x16VCU_BRKPEDST_UNPRESSED\x10\x00\x12\x18\n\x14VCU_BRKPEDST_PRESSED\x10\x01\"\xa3\x01\n\x0eVcu_intidxType\x12\x14\n\x10VCU_INTIDX_NOINT\x10\x00\x12\x17\n\x13VCU_INTIDX_OVERFLOW\x10\x01\x12\x16\n\x12VCU_INTIDX_TIMEOUT\x10\x02\x12\x18\n\x14VCU_INTIDX_ACCPEDINT\x10\x03\x12\x18\n\x14VCU_INTIDX_BRKPEDINT\x10\x04\x12\x16\n\x12VCU_INTIDX_GEARINT\x10\x05\"g\n\x12Vcu_gearintidxType\x12\x18\n\x14VCU_GEARINTIDX_NOINT\x10\x00\x12\x1b\n\x17VCU_GEARINTIDX_OVERFLOW\x10\x01\x12\x1a\n\x16VCU_GEARINTIDX_TIMEOUT\x10\x02\"\x87\x01\n\x13Vcu_geardrvmodeType\x12\x1b\n\x17VCU_GEARDRVMODE_INVALID\x10\x00\x12\x1a\n\x16VCU_GEARDRVMODE_MANUAL\x10\x01\x12\x1d\n\x19VCU_GEARDRVMODE_INTERRUPT\x10\x02\x12\x18\n\x14VCU_GEARDRVMODE_AUTO\x10\x03\"E\n\x10Vcu_vehrdystType\x12\x19\n\x15VCU_VEHRDYST_NOTREADY\x10\x00\x12\x16\n\x12VCU_VEHRDYST_READY\x10\x01\"\x9a\x01\n\x0fVcu_faultstType\x12\x16\n\x12VCU_FAULTST_NORMAL\x10\x00\x12\x16\n\x12VCU_FAULTST_DERATE\x10\x01\x12\x14\n\x10VCU_FAULTST_RSV1\x10\x02\x12\x14\n\x10VCU_FAULTST_RSV2\x10\x03\x12\x14\n\x10VCU_FAULTST_RSV3\x10\x04\x12\x15\n\x11VCU_FAULTST_FAULT\x10\x05\"s\n\x0fVcu_drvmodeType\x12\x17\n\x13VCU_DRVMODE_INVALID\x10\x00\x12\x16\n\x12VCU_DRVMODE_MANUAL\x10\x01\x12\x19\n\x15VCU_DRVMODE_INTERRUPT\x10\x02\x12\x14\n\x10VCU_DRVMODE_AUTO\x10\x03\"\x89\x01\n\x0fVcu_gearpstType\x12\x17\n\x13VCU_GEARPST_INVALID\x10\x00\x12\x15\n\x11VCU_GEARPST_DRIVE\x10\x01\x12\x17\n\x13VCU_GEARPST_NEUTRAL\x10\x02\x12\x17\n\x13VCU_GEARPST_REVERSE\x10\x03\x12\x14\n\x10VCU_GEARPST_PARK\x10\x04\"L\n\x13Vcu_gearfaultstType\x12\x1a\n\x16VCU_GEARFAULTST_NORMAL\x10\x00\x12\x19\n\x15VCU_GEARFAULTST_FAULT\x10\x01\"\x89\x01\n\x0fVcu_gearactType\x12\x17\n\x13VCU_GEARACT_INVALID\x10\x00\x12\x15\n\x11VCU_GEARACT_DRIVE\x10\x01\x12\x17\n\x13VCU_GEARACT_NEUTRAL\x10\x02\x12\x17\n\x13VCU_GEARACT_REVERSE\x10\x03\x12\x14\n\x10VCU_GEARACT_PARK\x10\x04\"\xaa\x04\n\x0bScu_eps_311\x12=\n\neps_intidx\x18\x01 \x01(\x0e\x32).apollo.canbus.Scu_eps_311.Eps_intidxType\x12\x19\n\x11\x65ps_steeranglespd\x18\x02 \x01(\x01\x12\x16\n\x0e\x65ps_steerangle\x18\x03 \x01(\x01\x12?\n\x0b\x65ps_faultst\x18\x04 \x01(\x0e\x32*.apollo.canbus.Scu_eps_311.Eps_faultstType\x12?\n\x0b\x65ps_drvmode\x18\x05 \x01(\x0e\x32*.apollo.canbus.Scu_eps_311.Eps_drvmodeType\"p\n\x0e\x45ps_intidxType\x12\x14\n\x10\x45PS_INTIDX_NOINT\x10\x00\x12\x17\n\x13\x45PS_INTIDX_OVERFLOW\x10\x01\x12\x16\n\x12\x45PS_INTIDX_TIMEOUT\x10\x02\x12\x17\n\x13\x45PS_INTIDX_STEERINT\x10\x03\"@\n\x0f\x45ps_faultstType\x12\x16\n\x12\x45PS_FAULTST_NORMAL\x10\x00\x12\x15\n\x11\x45PS_FAULTST_FAULT\x10\x01\"s\n\x0f\x45ps_drvmodeType\x12\x17\n\x13\x45PS_DRVMODE_INVALID\x10\x00\x12\x16\n\x12\x45PS_DRVMODE_MANUAL\x10\x01\x12\x19\n\x15\x45PS_DRVMODE_INTERRUPT\x10\x02\x12\x14\n\x10\x45PS_DRVMODE_AUTO\x10\x03\"\x93\x06\n\x03Ge3\x12-\n\npc_bcm_201\x18\x01 \x01(\x0b\x32\x19.apollo.canbus.Pc_bcm_201\x12\x33\n\rscu_bcs_3_308\x18\x02 \x01(\x0b\x32\x1c.apollo.canbus.Scu_bcs_3_308\x12-\n\npc_epb_203\x18\x03 \x01(\x0b\x32\x19.apollo.canbus.Pc_epb_203\x12-\n\npc_bcs_202\x18\x04 \x01(\x0b\x32\x19.apollo.canbus.Pc_bcs_202\x12-\n\npc_vcu_205\x18\x05 \x01(\x0b\x32\x19.apollo.canbus.Pc_vcu_205\x12-\n\npc_eps_204\x18\x06 \x01(\x0b\x32\x19.apollo.canbus.Pc_eps_204\x12\x33\n\rscu_vcu_2_313\x18\x07 \x01(\x0b\x32\x1c.apollo.canbus.Scu_vcu_2_313\x12+\n\tscu_1_301\x18\x08 \x01(\x0b\x32\x18.apollo.canbus.Scu_1_301\x12+\n\tscu_2_302\x18\t \x01(\x0b\x32\x18.apollo.canbus.Scu_2_302\x12+\n\tscu_3_303\x18\n \x01(\x0b\x32\x18.apollo.canbus.Scu_3_303\x12/\n\x0bscu_bcm_304\x18\x0b \x01(\x0b\x32\x1a.apollo.canbus.Scu_bcm_304\x12\x33\n\rscu_bcs_1_306\x18\x0c \x01(\x0b\x32\x1c.apollo.canbus.Scu_bcs_1_306\x12\x33\n\rscu_bcs_2_307\x18\r \x01(\x0b\x32\x1c.apollo.canbus.Scu_bcs_2_307\x12/\n\x0bscu_epb_310\x18\x0e \x01(\x0b\x32\x1a.apollo.canbus.Scu_epb_310\x12\x33\n\rscu_vcu_1_312\x18\x0f \x01(\x0b\x32\x1c.apollo.canbus.Scu_vcu_1_312\x12/\n\x0bscu_eps_311\x18\x10 \x01(\x0b\x32\x1a.apollo.canbus.Scu_eps_311'
)



_PC_BCM_201_PC_REVERSELAMPREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_reverselampreqType',
  full_name='apollo.canbus.Pc_bcm_201.Pc_reverselampreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_REVERSELAMPREQ_NOREQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_REVERSELAMPREQ_REQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=572,
  serialized_end=651,
)
_sym_db.RegisterEnumDescriptor(_PC_BCM_201_PC_REVERSELAMPREQTYPE)

_PC_BCM_201_PC_LOWBEAMREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_lowbeamreqType',
  full_name='apollo.canbus.Pc_bcm_201.Pc_lowbeamreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_LOWBEAMREQ_NOREQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_LOWBEAMREQ_REQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=653,
  serialized_end=720,
)
_sym_db.RegisterEnumDescriptor(_PC_BCM_201_PC_LOWBEAMREQTYPE)

_PC_BCM_201_PC_HIGHBEAMREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_highbeamreqType',
  full_name='apollo.canbus.Pc_bcm_201.Pc_highbeamreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_HIGHBEAMREQ_NOREQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_HIGHBEAMREQ_REQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=722,
  serialized_end=792,
)
_sym_db.RegisterEnumDescriptor(_PC_BCM_201_PC_HIGHBEAMREQTYPE)

_PC_BCM_201_PC_RIGHTTURNLAMPREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_rightturnlampreqType',
  full_name='apollo.canbus.Pc_bcm_201.Pc_rightturnlampreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_RIGHTTURNLAMPREQ_NOREQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_RIGHTTURNLAMPREQ_REQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=794,
  serialized_end=879,
)
_sym_db.RegisterEnumDescriptor(_PC_BCM_201_PC_RIGHTTURNLAMPREQTYPE)

_PC_BCM_201_PC_LEFTTURNLAMPREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_leftturnlampreqType',
  full_name='apollo.canbus.Pc_bcm_201.Pc_leftturnlampreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_LEFTTURNLAMPREQ_NOREQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_LEFTTURNLAMPREQ_REQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=881,
  serialized_end=963,
)
_sym_db.RegisterEnumDescriptor(_PC_BCM_201_PC_LEFTTURNLAMPREQTYPE)

_PC_BCM_201_PC_HORNREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_hornreqType',
  full_name='apollo.canbus.Pc_bcm_201.Pc_hornreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_HORNREQ_NOREQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_HORNREQ_REQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=965,
  serialized_end=1023,
)
_sym_db.RegisterEnumDescriptor(_PC_BCM_201_PC_HORNREQTYPE)

_PC_BCM_201_PC_HAZARDLAMPREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_hazardlampreqType',
  full_name='apollo.canbus.Pc_bcm_201.Pc_hazardlampreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_HAZARDLAMPREQ_NOREQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_HAZARDLAMPREQ_REQ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1025,
  serialized_end=1101,
)
_sym_db.RegisterEnumDescriptor(_PC_BCM_201_PC_HAZARDLAMPREQTYPE)

_SCU_BCS_3_308_BCS_RRWHEELSPDVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_rrwheelspdvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_rrwheelspdvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_RRWHEELSPDVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_RRWHEELSPDVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2221,
  serialized_end=2301,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_RRWHEELSPDVDTYPE)

_SCU_BCS_3_308_BCS_RRWHEELDIRECTIONVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_rrwheeldirectionvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_rrwheeldirectionvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_RRWHEELDIRECTIONVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_RRWHEELDIRECTIONVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2303,
  serialized_end=2401,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_RRWHEELDIRECTIONVDTYPE)

_SCU_BCS_3_308_BCS_RLWHEELSPDVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_rlwheelspdvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_rlwheelspdvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_RLWHEELSPDVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_RLWHEELSPDVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2403,
  serialized_end=2483,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_RLWHEELSPDVDTYPE)

_SCU_BCS_3_308_BCS_RLWHEELDIRECTIONVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_rlwheeldirectionvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_rlwheeldirectionvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_RLWHEELDIRECTIONVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_RLWHEELDIRECTIONVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2485,
  serialized_end=2583,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_RLWHEELDIRECTIONVDTYPE)

_SCU_BCS_3_308_BCS_FRWHEELSPDVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_frwheelspdvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_frwheelspdvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_FRWHEELSPDVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_FRWHEELSPDVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2585,
  serialized_end=2665,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_FRWHEELSPDVDTYPE)

_SCU_BCS_3_308_BCS_FRWHEELDIRECTIONVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_frwheeldirectionvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_frwheeldirectionvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_FRWHEELDIRECTIONVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_FRWHEELDIRECTIONVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2667,
  serialized_end=2765,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_FRWHEELDIRECTIONVDTYPE)

_SCU_BCS_3_308_BCS_FLWHEELSPDVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_flwheelspdvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_flwheelspdvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_FLWHEELSPDVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_FLWHEELSPDVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2767,
  serialized_end=2847,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_FLWHEELSPDVDTYPE)

_SCU_BCS_3_308_BCS_FLWHEELDIRECTIONVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_flwheeldirectionvdType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_flwheeldirectionvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_FLWHEELDIRECTIONVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_FLWHEELDIRECTIONVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2849,
  serialized_end=2947,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_FLWHEELDIRECTIONVDTYPE)

_SCU_BCS_3_308_BCS_RRWHEELDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='Bcs_rrwheeldirectionType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_rrwheeldirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_RRWHEELDIRECTION_FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_RRWHEELDIRECTION_BACKWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2949,
  serialized_end=3044,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_RRWHEELDIRECTIONTYPE)

_SCU_BCS_3_308_BCS_RLWHEELDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='Bcs_rlwheeldirectionType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_rlwheeldirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_RLWHEELDIRECTION_FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_RLWHEELDIRECTION_BACKWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3046,
  serialized_end=3141,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_RLWHEELDIRECTIONTYPE)

_SCU_BCS_3_308_BCS_FRWHEELDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='Bcs_frwheeldirectionType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_frwheeldirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_FRWHEELDIRECTION_FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_FRWHEELDIRECTION_BACKWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3143,
  serialized_end=3238,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_FRWHEELDIRECTIONTYPE)

_SCU_BCS_3_308_BCS_FLWHEELDIRECTIONTYPE = _descriptor.EnumDescriptor(
  name='Bcs_flwheeldirectionType',
  full_name='apollo.canbus.Scu_bcs_3_308.Bcs_flwheeldirectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_FLWHEELDIRECTION_FORWARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_FLWHEELDIRECTION_BACKWARD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3240,
  serialized_end=3335,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_3_308_BCS_FLWHEELDIRECTIONTYPE)

_PC_EPB_203_PC_EPBREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_epbreqType',
  full_name='apollo.canbus.Pc_epb_203.Pc_epbreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_EPBREQ_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_EPBREQ_RELEASE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_EPBREQ_APPLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3478,
  serialized_end=3560,
)
_sym_db.RegisterEnumDescriptor(_PC_EPB_203_PC_EPBREQTYPE)

_PC_EPB_203_PC_EPBENABLETYPE = _descriptor.EnumDescriptor(
  name='Pc_epbenableType',
  full_name='apollo.canbus.Pc_epb_203.Pc_epbenableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_EPBENABLE_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_EPBENABLE_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3562,
  serialized_end=3631,
)
_sym_db.RegisterEnumDescriptor(_PC_EPB_203_PC_EPBENABLETYPE)

_PC_BCS_202_PC_BRKPEDENABLETYPE = _descriptor.EnumDescriptor(
  name='Pc_brkpedenableType',
  full_name='apollo.canbus.Pc_bcs_202.Pc_brkpedenableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_BRKPEDENABLE_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_BRKPEDENABLE_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3742,
  serialized_end=3820,
)
_sym_db.RegisterEnumDescriptor(_PC_BCS_202_PC_BRKPEDENABLETYPE)

_PC_VCU_205_PC_ACCPEDENABLETYPE = _descriptor.EnumDescriptor(
  name='Pc_accpedenableType',
  full_name='apollo.canbus.Pc_vcu_205.Pc_accpedenableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_ACCPEDENABLE_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_ACCPEDENABLE_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4149,
  serialized_end=4227,
)
_sym_db.RegisterEnumDescriptor(_PC_VCU_205_PC_ACCPEDENABLETYPE)

_PC_VCU_205_PC_TORQENABLETYPE = _descriptor.EnumDescriptor(
  name='Pc_torqenableType',
  full_name='apollo.canbus.Pc_vcu_205.Pc_torqenableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_TORQENABLE_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_TORQENABLE_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4229,
  serialized_end=4301,
)
_sym_db.RegisterEnumDescriptor(_PC_VCU_205_PC_TORQENABLETYPE)

_PC_VCU_205_PC_GEARREQTYPE = _descriptor.EnumDescriptor(
  name='Pc_gearreqType',
  full_name='apollo.canbus.Pc_vcu_205.Pc_gearreqType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_GEARREQ_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_GEARREQ_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_GEARREQ_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_GEARREQ_REVERSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_GEARREQ_PARK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4304,
  serialized_end=4435,
)
_sym_db.RegisterEnumDescriptor(_PC_VCU_205_PC_GEARREQTYPE)

_PC_VCU_205_PC_GEARENABLETYPE = _descriptor.EnumDescriptor(
  name='Pc_gearenableType',
  full_name='apollo.canbus.Pc_vcu_205.Pc_gearenableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_GEARENABLE_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_GEARENABLE_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4437,
  serialized_end=4509,
)
_sym_db.RegisterEnumDescriptor(_PC_VCU_205_PC_GEARENABLETYPE)

_PC_EPS_204_PC_STEERENABLETYPE = _descriptor.EnumDescriptor(
  name='Pc_steerenableType',
  full_name='apollo.canbus.Pc_eps_204.Pc_steerenableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PC_STEERENABLE_DISABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PC_STEERENABLE_ENABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4644,
  serialized_end=4719,
)
_sym_db.RegisterEnumDescriptor(_PC_EPS_204_PC_STEERENABLETYPE)

_SCU_1_301_SCU_STOPBUTSTTYPE = _descriptor.EnumDescriptor(
  name='Scu_stopbutstType',
  full_name='apollo.canbus.Scu_1_301.Scu_stopbutstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCU_STOPBUTST_UNPRESSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCU_STOPBUTST_PRESSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5049,
  serialized_end=5124,
)
_sym_db.RegisterEnumDescriptor(_SCU_1_301_SCU_STOPBUTSTTYPE)

_SCU_1_301_SCU_DRVMODETYPE = _descriptor.EnumDescriptor(
  name='Scu_drvmodeType',
  full_name='apollo.canbus.Scu_1_301.Scu_drvmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCU_DRVMODE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCU_DRVMODE_MANUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCU_DRVMODE_INTERRUPT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCU_DRVMODE_AUTO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5126,
  serialized_end=5241,
)
_sym_db.RegisterEnumDescriptor(_SCU_1_301_SCU_DRVMODETYPE)

_SCU_1_301_SCU_FAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Scu_faultstType',
  full_name='apollo.canbus.Scu_1_301.Scu_faultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCU_FAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCU_FAULTST_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5243,
  serialized_end=5307,
)
_sym_db.RegisterEnumDescriptor(_SCU_1_301_SCU_FAULTSTTYPE)

_SCU_BCM_304_BCM_VEHREVERSESTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_vehreversestType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_vehreversestType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_VEHREVERSEST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_VEHREVERSEST_REVERSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6487,
  serialized_end=6568,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_VEHREVERSESTTYPE)

_SCU_BCM_304_BCM_RIGHTTURNLAMPSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_rightturnlampstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_rightturnlampstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_RIGHTTURNLAMPST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_RIGHTTURNLAMPST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6570,
  serialized_end=6661,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_RIGHTTURNLAMPSTTYPE)

_SCU_BCM_304_BCM_REARFOGLAMPSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_rearfoglampstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_rearfoglampstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_REARFOGLAMPST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_REARFOGLAMPST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6663,
  serialized_end=6748,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_REARFOGLAMPSTTYPE)

_SCU_BCM_304_BCM_PARKINGLAMPSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_parkinglampstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_parkinglampstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_PARKINGLAMPST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_PARKINGLAMPST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6750,
  serialized_end=6835,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_PARKINGLAMPSTTYPE)

_SCU_BCM_304_BCM_LOWBEAMSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_lowbeamstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_lowbeamstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_LOWBEAMST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_LOWBEAMST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6837,
  serialized_end=6910,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_LOWBEAMSTTYPE)

_SCU_BCM_304_BCM_LEFTTURNLAMPSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_leftturnlampstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_leftturnlampstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_LEFTTURNLAMPST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_LEFTTURNLAMPST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6912,
  serialized_end=7000,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_LEFTTURNLAMPSTTYPE)

_SCU_BCM_304_BCM_KEYSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_keystType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_keystType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_KEYST_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_KEYST_ACC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_KEYST_ON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_KEYST_CRANK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7002,
  serialized_end=7094,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_KEYSTTYPE)

_SCU_BCM_304_BCM_HORNSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_hornstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_hornstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_HORNST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_HORNST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7096,
  serialized_end=7160,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_HORNSTTYPE)

_SCU_BCM_304_BCM_HIGHBEAMSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_highbeamstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_highbeamstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_HIGHBEAMST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_HIGHBEAMST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7162,
  serialized_end=7238,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_HIGHBEAMSTTYPE)

_SCU_BCM_304_BCM_HAZARDLAMPSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_hazardlampstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_hazardlampstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_HAZARDLAMPST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_HAZARDLAMPST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7240,
  serialized_end=7322,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_HAZARDLAMPSTTYPE)

_SCU_BCM_304_BCM_FRONTFOGLAMPSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_frontfoglampstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_frontfoglampstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_FRONTFOGLAMPST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_FRONTFOGLAMPST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7324,
  serialized_end=7412,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_FRONTFOGLAMPSTTYPE)

_SCU_BCM_304_BCM_BRAKELIGHTSWITCHSTTYPE = _descriptor.EnumDescriptor(
  name='Bcm_brakelightswitchstType',
  full_name='apollo.canbus.Scu_bcm_304.Bcm_brakelightswitchstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCM_BRAKELIGHTSWITCHST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCM_BRAKELIGHTSWITCHST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7414,
  serialized_end=7514,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCM_304_BCM_BRAKELIGHTSWITCHSTTYPE)

_SCU_BCS_1_306_BCS_AEBAVAILABLETYPE = _descriptor.EnumDescriptor(
  name='Bcs_aebavailableType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_aebavailableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_AEBAVAILABLE_UNAVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_AEBAVAILABLE_AVAILABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8206,
  serialized_end=8294,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_AEBAVAILABLETYPE)

_SCU_BCS_1_306_BCS_CDDAVAILABLETYPE = _descriptor.EnumDescriptor(
  name='Bcs_cddavailableType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_cddavailableType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_CDDAVAILABLE_UNAVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_CDDAVAILABLE_AVAILABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8296,
  serialized_end=8384,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_CDDAVAILABLETYPE)

_SCU_BCS_1_306_BCS_INTIDXTYPE = _descriptor.EnumDescriptor(
  name='Bcs_intidxType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_intidxType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_INTIDX_NOINT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_INTIDX_OVERFLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_INTIDX_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_INTIDX_ACCPEDINT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_INTIDX_BRKPEDINT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_INTIDX_GEARINT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8387,
  serialized_end=8550,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_INTIDXTYPE)

_SCU_BCS_1_306_BCS_VDCFAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Bcs_vdcfaultstType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_vdcfaultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_VDCFAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_VDCFAULTST_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8552,
  serialized_end=8625,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_VDCFAULTSTTYPE)

_SCU_BCS_1_306_BCS_VDCACTIVESTTYPE = _descriptor.EnumDescriptor(
  name='Bcs_vdcactivestType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_vdcactivestType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_VDCACTIVEST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_VDCACTIVEST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8627,
  serialized_end=8706,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_VDCACTIVESTTYPE)

_SCU_BCS_1_306_BCS_ABSFAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Bcs_absfaultstType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_absfaultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_ABSFAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_ABSFAULTST_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8708,
  serialized_end=8781,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_ABSFAULTSTTYPE)

_SCU_BCS_1_306_BCS_ABSACTIVESTTYPE = _descriptor.EnumDescriptor(
  name='Bcs_absactivestType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_absactivestType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_ABSACTIVEST_INACTIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_ABSACTIVEST_ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8783,
  serialized_end=8862,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_ABSACTIVESTTYPE)

_SCU_BCS_1_306_BCS_FAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Bcs_faultstType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_faultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_FAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_FAULTST_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8864,
  serialized_end=8928,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_FAULTSTTYPE)

_SCU_BCS_1_306_BCS_DRVMODETYPE = _descriptor.EnumDescriptor(
  name='Bcs_drvmodeType',
  full_name='apollo.canbus.Scu_bcs_1_306.Bcs_drvmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_DRVMODE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_DRVMODE_MANUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_DRVMODE_INTERRUPT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_DRVMODE_AUTO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8930,
  serialized_end=9045,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_1_306_BCS_DRVMODETYPE)

_SCU_BCS_2_307_BCS_VEHSPDVDTYPE = _descriptor.EnumDescriptor(
  name='Bcs_vehspdvdType',
  full_name='apollo.canbus.Scu_bcs_2_307.Bcs_vehspdvdType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BCS_VEHSPDVD_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BCS_VEHSPDVD_VALID', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9226,
  serialized_end=9294,
)
_sym_db.RegisterEnumDescriptor(_SCU_BCS_2_307_BCS_VEHSPDVDTYPE)

_SCU_EPB_310_EPB_INTIDXTYPE = _descriptor.EnumDescriptor(
  name='Epb_intidxType',
  full_name='apollo.canbus.Scu_epb_310.Epb_intidxType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPB_INTIDX_NOINT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_INTIDX_OVERFLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_INTIDX_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9566,
  serialized_end=9653,
)
_sym_db.RegisterEnumDescriptor(_SCU_EPB_310_EPB_INTIDXTYPE)

_SCU_EPB_310_EPB_DRVMODETYPE = _descriptor.EnumDescriptor(
  name='Epb_drvmodeType',
  full_name='apollo.canbus.Scu_epb_310.Epb_drvmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPB_DRVMODE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_DRVMODE_MANUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_DRVMODE_INTERRUPT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_DRVMODE_AUTO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9655,
  serialized_end=9770,
)
_sym_db.RegisterEnumDescriptor(_SCU_EPB_310_EPB_DRVMODETYPE)

_SCU_EPB_310_EPB_SYSSTTYPE = _descriptor.EnumDescriptor(
  name='Epb_sysstType',
  full_name='apollo.canbus.Scu_epb_310.Epb_sysstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPB_SYSST_RELEASED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_SYSST_APPLIED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_SYSST_RELEASING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_SYSST_FAULT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_SYSST_APPLYING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_SYSST_DISENGAGED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9773,
  serialized_end=9931,
)
_sym_db.RegisterEnumDescriptor(_SCU_EPB_310_EPB_SYSSTTYPE)

_SCU_EPB_310_EPB_FAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Epb_faultstType',
  full_name='apollo.canbus.Scu_epb_310.Epb_faultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPB_FAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPB_FAULTST_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9933,
  serialized_end=9997,
)
_sym_db.RegisterEnumDescriptor(_SCU_EPB_310_EPB_FAULTSTTYPE)

_SCU_VCU_1_312_VCU_ELCSYSFAULTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_elcsysfaultType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_elcsysfaultType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_ELCSYSFAULT_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_ELCSYSFAULT_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10875,
  serialized_end=10951,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_ELCSYSFAULTTYPE)

_SCU_VCU_1_312_VCU_BRKPEDSTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_brkpedstType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_brkpedstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_BRKPEDST_UNPRESSED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_BRKPEDST_PRESSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10953,
  serialized_end=11025,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_BRKPEDSTTYPE)

_SCU_VCU_1_312_VCU_INTIDXTYPE = _descriptor.EnumDescriptor(
  name='Vcu_intidxType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_intidxType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_INTIDX_NOINT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_INTIDX_OVERFLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_INTIDX_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_INTIDX_ACCPEDINT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_INTIDX_BRKPEDINT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_INTIDX_GEARINT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11028,
  serialized_end=11191,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_INTIDXTYPE)

_SCU_VCU_1_312_VCU_GEARINTIDXTYPE = _descriptor.EnumDescriptor(
  name='Vcu_gearintidxType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_gearintidxType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARINTIDX_NOINT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARINTIDX_OVERFLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARINTIDX_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11193,
  serialized_end=11296,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_GEARINTIDXTYPE)

_SCU_VCU_1_312_VCU_GEARDRVMODETYPE = _descriptor.EnumDescriptor(
  name='Vcu_geardrvmodeType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_geardrvmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARDRVMODE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARDRVMODE_MANUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARDRVMODE_INTERRUPT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARDRVMODE_AUTO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11299,
  serialized_end=11434,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_GEARDRVMODETYPE)

_SCU_VCU_1_312_VCU_VEHRDYSTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_vehrdystType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_vehrdystType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_VEHRDYST_NOTREADY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_VEHRDYST_READY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11436,
  serialized_end=11505,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_VEHRDYSTTYPE)

_SCU_VCU_1_312_VCU_FAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_faultstType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_faultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_FAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_FAULTST_DERATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_FAULTST_RSV1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_FAULTST_RSV2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_FAULTST_RSV3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_FAULTST_FAULT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11508,
  serialized_end=11662,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_FAULTSTTYPE)

_SCU_VCU_1_312_VCU_DRVMODETYPE = _descriptor.EnumDescriptor(
  name='Vcu_drvmodeType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_drvmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_DRVMODE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_DRVMODE_MANUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_DRVMODE_INTERRUPT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_DRVMODE_AUTO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11664,
  serialized_end=11779,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_DRVMODETYPE)

_SCU_VCU_1_312_VCU_GEARPSTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_gearpstType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_gearpstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARPST_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARPST_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARPST_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARPST_REVERSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARPST_PARK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11782,
  serialized_end=11919,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_GEARPSTTYPE)

_SCU_VCU_1_312_VCU_GEARFAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_gearfaultstType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_gearfaultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARFAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARFAULTST_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11921,
  serialized_end=11997,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_GEARFAULTSTTYPE)

_SCU_VCU_1_312_VCU_GEARACTTYPE = _descriptor.EnumDescriptor(
  name='Vcu_gearactType',
  full_name='apollo.canbus.Scu_vcu_1_312.Vcu_gearactType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARACT_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARACT_DRIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARACT_NEUTRAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARACT_REVERSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VCU_GEARACT_PARK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12000,
  serialized_end=12137,
)
_sym_db.RegisterEnumDescriptor(_SCU_VCU_1_312_VCU_GEARACTTYPE)

_SCU_EPS_311_EPS_INTIDXTYPE = _descriptor.EnumDescriptor(
  name='Eps_intidxType',
  full_name='apollo.canbus.Scu_eps_311.Eps_intidxType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPS_INTIDX_NOINT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_INTIDX_OVERFLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_INTIDX_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_INTIDX_STEERINT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12399,
  serialized_end=12511,
)
_sym_db.RegisterEnumDescriptor(_SCU_EPS_311_EPS_INTIDXTYPE)

_SCU_EPS_311_EPS_FAULTSTTYPE = _descriptor.EnumDescriptor(
  name='Eps_faultstType',
  full_name='apollo.canbus.Scu_eps_311.Eps_faultstType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPS_FAULTST_NORMAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_FAULTST_FAULT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12513,
  serialized_end=12577,
)
_sym_db.RegisterEnumDescriptor(_SCU_EPS_311_EPS_FAULTSTTYPE)

_SCU_EPS_311_EPS_DRVMODETYPE = _descriptor.EnumDescriptor(
  name='Eps_drvmodeType',
  full_name='apollo.canbus.Scu_eps_311.Eps_drvmodeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EPS_DRVMODE_INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_DRVMODE_MANUAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_DRVMODE_INTERRUPT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPS_DRVMODE_AUTO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12579,
  serialized_end=12694,
)
_sym_db.RegisterEnumDescriptor(_SCU_EPS_311_EPS_DRVMODETYPE)


_PC_BCM_201 = _descriptor.Descriptor(
  name='Pc_bcm_201',
  full_name='apollo.canbus.Pc_bcm_201',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pc_reverselampreq', full_name='apollo.canbus.Pc_bcm_201.pc_reverselampreq', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_lowbeamreq', full_name='apollo.canbus.Pc_bcm_201.pc_lowbeamreq', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_highbeamreq', full_name='apollo.canbus.Pc_bcm_201.pc_highbeamreq', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_rightturnlampreq', full_name='apollo.canbus.Pc_bcm_201.pc_rightturnlampreq', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_leftturnlampreq', full_name='apollo.canbus.Pc_bcm_201.pc_leftturnlampreq', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_hornreq', full_name='apollo.canbus.Pc_bcm_201.pc_hornreq', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_hazardlampreq', full_name='apollo.canbus.Pc_bcm_201.pc_hazardlampreq', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PC_BCM_201_PC_REVERSELAMPREQTYPE,
    _PC_BCM_201_PC_LOWBEAMREQTYPE,
    _PC_BCM_201_PC_HIGHBEAMREQTYPE,
    _PC_BCM_201_PC_RIGHTTURNLAMPREQTYPE,
    _PC_BCM_201_PC_LEFTTURNLAMPREQTYPE,
    _PC_BCM_201_PC_HORNREQTYPE,
    _PC_BCM_201_PC_HAZARDLAMPREQTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=1101,
)


_SCU_BCS_3_308 = _descriptor.Descriptor(
  name='Scu_bcs_3_308',
  full_name='apollo.canbus.Scu_bcs_3_308',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bcs_rrwheelspdvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rrwheelspdvd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_rrwheeldirectionvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rrwheeldirectionvd', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_rlwheelspdvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rlwheelspdvd', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_rlwheeldirectionvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rlwheeldirectionvd', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_frwheelspdvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_frwheelspdvd', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_frwheeldirectionvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_frwheeldirectionvd', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_flwheelspdvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_flwheelspdvd', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_flwheeldirectionvd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_flwheeldirectionvd', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_rrwheelspd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rrwheelspd', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_rrwheeldirection', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rrwheeldirection', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_rlwheelspd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rlwheelspd', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_rlwheeldirection', full_name='apollo.canbus.Scu_bcs_3_308.bcs_rlwheeldirection', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_frwheelspd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_frwheelspd', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_frwheeldirection', full_name='apollo.canbus.Scu_bcs_3_308.bcs_frwheeldirection', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_flwheelspd', full_name='apollo.canbus.Scu_bcs_3_308.bcs_flwheelspd', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_flwheeldirection', full_name='apollo.canbus.Scu_bcs_3_308.bcs_flwheeldirection', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_BCS_3_308_BCS_RRWHEELSPDVDTYPE,
    _SCU_BCS_3_308_BCS_RRWHEELDIRECTIONVDTYPE,
    _SCU_BCS_3_308_BCS_RLWHEELSPDVDTYPE,
    _SCU_BCS_3_308_BCS_RLWHEELDIRECTIONVDTYPE,
    _SCU_BCS_3_308_BCS_FRWHEELSPDVDTYPE,
    _SCU_BCS_3_308_BCS_FRWHEELDIRECTIONVDTYPE,
    _SCU_BCS_3_308_BCS_FLWHEELSPDVDTYPE,
    _SCU_BCS_3_308_BCS_FLWHEELDIRECTIONVDTYPE,
    _SCU_BCS_3_308_BCS_RRWHEELDIRECTIONTYPE,
    _SCU_BCS_3_308_BCS_RLWHEELDIRECTIONTYPE,
    _SCU_BCS_3_308_BCS_FRWHEELDIRECTIONTYPE,
    _SCU_BCS_3_308_BCS_FLWHEELDIRECTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=3335,
)


_PC_EPB_203 = _descriptor.Descriptor(
  name='Pc_epb_203',
  full_name='apollo.canbus.Pc_epb_203',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pc_epbreq', full_name='apollo.canbus.Pc_epb_203.pc_epbreq', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_epbenable', full_name='apollo.canbus.Pc_epb_203.pc_epbenable', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PC_EPB_203_PC_EPBREQTYPE,
    _PC_EPB_203_PC_EPBENABLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3338,
  serialized_end=3631,
)


_PC_BCS_202 = _descriptor.Descriptor(
  name='Pc_bcs_202',
  full_name='apollo.canbus.Pc_bcs_202',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pc_brkpedreq', full_name='apollo.canbus.Pc_bcs_202.pc_brkpedreq', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_brkpedenable', full_name='apollo.canbus.Pc_bcs_202.pc_brkpedenable', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PC_BCS_202_PC_BRKPEDENABLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3634,
  serialized_end=3820,
)


_PC_VCU_205 = _descriptor.Descriptor(
  name='Pc_vcu_205',
  full_name='apollo.canbus.Pc_vcu_205',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pc_accpedreq', full_name='apollo.canbus.Pc_vcu_205.pc_accpedreq', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_accpedenable', full_name='apollo.canbus.Pc_vcu_205.pc_accpedenable', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_torqreq', full_name='apollo.canbus.Pc_vcu_205.pc_torqreq', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_torqenable', full_name='apollo.canbus.Pc_vcu_205.pc_torqenable', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_gearreq', full_name='apollo.canbus.Pc_vcu_205.pc_gearreq', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_gearenable', full_name='apollo.canbus.Pc_vcu_205.pc_gearenable', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PC_VCU_205_PC_ACCPEDENABLETYPE,
    _PC_VCU_205_PC_TORQENABLETYPE,
    _PC_VCU_205_PC_GEARREQTYPE,
    _PC_VCU_205_PC_GEARENABLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3823,
  serialized_end=4509,
)


_PC_EPS_204 = _descriptor.Descriptor(
  name='Pc_eps_204',
  full_name='apollo.canbus.Pc_eps_204',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pc_steerspdreq', full_name='apollo.canbus.Pc_eps_204.pc_steerspdreq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_steerenable', full_name='apollo.canbus.Pc_eps_204.pc_steerenable', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_steerangreq', full_name='apollo.canbus.Pc_eps_204.pc_steerangreq', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PC_EPS_204_PC_STEERENABLETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4512,
  serialized_end=4719,
)


_SCU_VCU_2_313 = _descriptor.Descriptor(
  name='Scu_vcu_2_313',
  full_name='apollo.canbus.Scu_vcu_2_313',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vcu_torqposmax', full_name='apollo.canbus.Scu_vcu_2_313.vcu_torqposmax', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_torqnegmax', full_name='apollo.canbus.Scu_vcu_2_313.vcu_torqnegmax', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_torqact', full_name='apollo.canbus.Scu_vcu_2_313.vcu_torqact', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_engspd', full_name='apollo.canbus.Scu_vcu_2_313.vcu_engspd', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4721,
  serialized_end=4825,
)


_SCU_1_301 = _descriptor.Descriptor(
  name='Scu_1_301',
  full_name='apollo.canbus.Scu_1_301',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vin16', full_name='apollo.canbus.Scu_1_301.vin16', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_stopbutst', full_name='apollo.canbus.Scu_1_301.scu_stopbutst', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_drvmode', full_name='apollo.canbus.Scu_1_301.scu_drvmode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_faultst', full_name='apollo.canbus.Scu_1_301.scu_faultst', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_1_301_SCU_STOPBUTSTTYPE,
    _SCU_1_301_SCU_DRVMODETYPE,
    _SCU_1_301_SCU_FAULTSTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4828,
  serialized_end=5307,
)


_SCU_2_302 = _descriptor.Descriptor(
  name='Scu_2_302',
  full_name='apollo.canbus.Scu_2_302',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vin07', full_name='apollo.canbus.Scu_2_302.vin07', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin06', full_name='apollo.canbus.Scu_2_302.vin06', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin05', full_name='apollo.canbus.Scu_2_302.vin05', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin04', full_name='apollo.canbus.Scu_2_302.vin04', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin03', full_name='apollo.canbus.Scu_2_302.vin03', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin02', full_name='apollo.canbus.Scu_2_302.vin02', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin01', full_name='apollo.canbus.Scu_2_302.vin01', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin00', full_name='apollo.canbus.Scu_2_302.vin00', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5310,
  serialized_end=5441,
)


_SCU_3_303 = _descriptor.Descriptor(
  name='Scu_3_303',
  full_name='apollo.canbus.Scu_3_303',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vin15', full_name='apollo.canbus.Scu_3_303.vin15', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin14', full_name='apollo.canbus.Scu_3_303.vin14', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin13', full_name='apollo.canbus.Scu_3_303.vin13', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin12', full_name='apollo.canbus.Scu_3_303.vin12', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin11', full_name='apollo.canbus.Scu_3_303.vin11', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin10', full_name='apollo.canbus.Scu_3_303.vin10', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin09', full_name='apollo.canbus.Scu_3_303.vin09', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vin08', full_name='apollo.canbus.Scu_3_303.vin08', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5444,
  serialized_end=5575,
)


_SCU_BCM_304 = _descriptor.Descriptor(
  name='Scu_bcm_304',
  full_name='apollo.canbus.Scu_bcm_304',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bcm_vehreversest', full_name='apollo.canbus.Scu_bcm_304.bcm_vehreversest', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_rightturnlampst', full_name='apollo.canbus.Scu_bcm_304.bcm_rightturnlampst', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_rearfoglampst', full_name='apollo.canbus.Scu_bcm_304.bcm_rearfoglampst', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_parkinglampst', full_name='apollo.canbus.Scu_bcm_304.bcm_parkinglampst', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_lowbeamst', full_name='apollo.canbus.Scu_bcm_304.bcm_lowbeamst', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_leftturnlampst', full_name='apollo.canbus.Scu_bcm_304.bcm_leftturnlampst', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_keyst', full_name='apollo.canbus.Scu_bcm_304.bcm_keyst', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_hornst', full_name='apollo.canbus.Scu_bcm_304.bcm_hornst', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_highbeamst', full_name='apollo.canbus.Scu_bcm_304.bcm_highbeamst', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_hazardlampst', full_name='apollo.canbus.Scu_bcm_304.bcm_hazardlampst', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_frontfoglampst', full_name='apollo.canbus.Scu_bcm_304.bcm_frontfoglampst', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcm_brakelightswitchst', full_name='apollo.canbus.Scu_bcm_304.bcm_brakelightswitchst', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_BCM_304_BCM_VEHREVERSESTTYPE,
    _SCU_BCM_304_BCM_RIGHTTURNLAMPSTTYPE,
    _SCU_BCM_304_BCM_REARFOGLAMPSTTYPE,
    _SCU_BCM_304_BCM_PARKINGLAMPSTTYPE,
    _SCU_BCM_304_BCM_LOWBEAMSTTYPE,
    _SCU_BCM_304_BCM_LEFTTURNLAMPSTTYPE,
    _SCU_BCM_304_BCM_KEYSTTYPE,
    _SCU_BCM_304_BCM_HORNSTTYPE,
    _SCU_BCM_304_BCM_HIGHBEAMSTTYPE,
    _SCU_BCM_304_BCM_HAZARDLAMPSTTYPE,
    _SCU_BCM_304_BCM_FRONTFOGLAMPSTTYPE,
    _SCU_BCM_304_BCM_BRAKELIGHTSWITCHSTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5578,
  serialized_end=7514,
)


_SCU_BCS_1_306 = _descriptor.Descriptor(
  name='Scu_bcs_1_306',
  full_name='apollo.canbus.Scu_bcs_1_306',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bcs_aebavailable', full_name='apollo.canbus.Scu_bcs_1_306.bcs_aebavailable', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_cddavailable', full_name='apollo.canbus.Scu_bcs_1_306.bcs_cddavailable', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_brkpedact', full_name='apollo.canbus.Scu_bcs_1_306.bcs_brkpedact', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_intidx', full_name='apollo.canbus.Scu_bcs_1_306.bcs_intidx', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_vdcfaultst', full_name='apollo.canbus.Scu_bcs_1_306.bcs_vdcfaultst', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_vdcactivest', full_name='apollo.canbus.Scu_bcs_1_306.bcs_vdcactivest', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_absfaultst', full_name='apollo.canbus.Scu_bcs_1_306.bcs_absfaultst', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_absactivest', full_name='apollo.canbus.Scu_bcs_1_306.bcs_absactivest', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_faultst', full_name='apollo.canbus.Scu_bcs_1_306.bcs_faultst', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_drvmode', full_name='apollo.canbus.Scu_bcs_1_306.bcs_drvmode', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_BCS_1_306_BCS_AEBAVAILABLETYPE,
    _SCU_BCS_1_306_BCS_CDDAVAILABLETYPE,
    _SCU_BCS_1_306_BCS_INTIDXTYPE,
    _SCU_BCS_1_306_BCS_VDCFAULTSTTYPE,
    _SCU_BCS_1_306_BCS_VDCACTIVESTTYPE,
    _SCU_BCS_1_306_BCS_ABSFAULTSTTYPE,
    _SCU_BCS_1_306_BCS_ABSACTIVESTTYPE,
    _SCU_BCS_1_306_BCS_FAULTSTTYPE,
    _SCU_BCS_1_306_BCS_DRVMODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7517,
  serialized_end=9045,
)


_SCU_BCS_2_307 = _descriptor.Descriptor(
  name='Scu_bcs_2_307',
  full_name='apollo.canbus.Scu_bcs_2_307',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bcs_vehspdvd', full_name='apollo.canbus.Scu_bcs_2_307.bcs_vehspdvd', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_yawrate', full_name='apollo.canbus.Scu_bcs_2_307.bcs_yawrate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_vehspd', full_name='apollo.canbus.Scu_bcs_2_307.bcs_vehspd', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_vehlongaccel', full_name='apollo.canbus.Scu_bcs_2_307.bcs_vehlongaccel', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bcs_vehlataccel', full_name='apollo.canbus.Scu_bcs_2_307.bcs_vehlataccel', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_BCS_2_307_BCS_VEHSPDVDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9048,
  serialized_end=9294,
)


_SCU_EPB_310 = _descriptor.Descriptor(
  name='Scu_epb_310',
  full_name='apollo.canbus.Scu_epb_310',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epb_intidx', full_name='apollo.canbus.Scu_epb_310.epb_intidx', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epb_drvmode', full_name='apollo.canbus.Scu_epb_310.epb_drvmode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epb_sysst', full_name='apollo.canbus.Scu_epb_310.epb_sysst', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epb_faultst', full_name='apollo.canbus.Scu_epb_310.epb_faultst', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_EPB_310_EPB_INTIDXTYPE,
    _SCU_EPB_310_EPB_DRVMODETYPE,
    _SCU_EPB_310_EPB_SYSSTTYPE,
    _SCU_EPB_310_EPB_FAULTSTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9297,
  serialized_end=9997,
)


_SCU_VCU_1_312 = _descriptor.Descriptor(
  name='Scu_vcu_1_312',
  full_name='apollo.canbus.Scu_vcu_1_312',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vcu_elcsysfault', full_name='apollo.canbus.Scu_vcu_1_312.vcu_elcsysfault', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_brkpedst', full_name='apollo.canbus.Scu_vcu_1_312.vcu_brkpedst', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_intidx', full_name='apollo.canbus.Scu_vcu_1_312.vcu_intidx', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_gearintidx', full_name='apollo.canbus.Scu_vcu_1_312.vcu_gearintidx', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_geardrvmode', full_name='apollo.canbus.Scu_vcu_1_312.vcu_geardrvmode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_accpedact', full_name='apollo.canbus.Scu_vcu_1_312.vcu_accpedact', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_brkpedpst', full_name='apollo.canbus.Scu_vcu_1_312.vcu_brkpedpst', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_vehrng', full_name='apollo.canbus.Scu_vcu_1_312.vcu_vehrng', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_accpedpst', full_name='apollo.canbus.Scu_vcu_1_312.vcu_accpedpst', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_vehrdyst', full_name='apollo.canbus.Scu_vcu_1_312.vcu_vehrdyst', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_faultst', full_name='apollo.canbus.Scu_vcu_1_312.vcu_faultst', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_drvmode', full_name='apollo.canbus.Scu_vcu_1_312.vcu_drvmode', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_gearpst', full_name='apollo.canbus.Scu_vcu_1_312.vcu_gearpst', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_gearfaultst', full_name='apollo.canbus.Scu_vcu_1_312.vcu_gearfaultst', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcu_gearact', full_name='apollo.canbus.Scu_vcu_1_312.vcu_gearact', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_VCU_1_312_VCU_ELCSYSFAULTTYPE,
    _SCU_VCU_1_312_VCU_BRKPEDSTTYPE,
    _SCU_VCU_1_312_VCU_INTIDXTYPE,
    _SCU_VCU_1_312_VCU_GEARINTIDXTYPE,
    _SCU_VCU_1_312_VCU_GEARDRVMODETYPE,
    _SCU_VCU_1_312_VCU_VEHRDYSTTYPE,
    _SCU_VCU_1_312_VCU_FAULTSTTYPE,
    _SCU_VCU_1_312_VCU_DRVMODETYPE,
    _SCU_VCU_1_312_VCU_GEARPSTTYPE,
    _SCU_VCU_1_312_VCU_GEARFAULTSTTYPE,
    _SCU_VCU_1_312_VCU_GEARACTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10000,
  serialized_end=12137,
)


_SCU_EPS_311 = _descriptor.Descriptor(
  name='Scu_eps_311',
  full_name='apollo.canbus.Scu_eps_311',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eps_intidx', full_name='apollo.canbus.Scu_eps_311.eps_intidx', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_steeranglespd', full_name='apollo.canbus.Scu_eps_311.eps_steeranglespd', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_steerangle', full_name='apollo.canbus.Scu_eps_311.eps_steerangle', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_faultst', full_name='apollo.canbus.Scu_eps_311.eps_faultst', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps_drvmode', full_name='apollo.canbus.Scu_eps_311.eps_drvmode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCU_EPS_311_EPS_INTIDXTYPE,
    _SCU_EPS_311_EPS_FAULTSTTYPE,
    _SCU_EPS_311_EPS_DRVMODETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12140,
  serialized_end=12694,
)


_GE3 = _descriptor.Descriptor(
  name='Ge3',
  full_name='apollo.canbus.Ge3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pc_bcm_201', full_name='apollo.canbus.Ge3.pc_bcm_201', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_bcs_3_308', full_name='apollo.canbus.Ge3.scu_bcs_3_308', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_epb_203', full_name='apollo.canbus.Ge3.pc_epb_203', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_bcs_202', full_name='apollo.canbus.Ge3.pc_bcs_202', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_vcu_205', full_name='apollo.canbus.Ge3.pc_vcu_205', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pc_eps_204', full_name='apollo.canbus.Ge3.pc_eps_204', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_vcu_2_313', full_name='apollo.canbus.Ge3.scu_vcu_2_313', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_1_301', full_name='apollo.canbus.Ge3.scu_1_301', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_2_302', full_name='apollo.canbus.Ge3.scu_2_302', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_3_303', full_name='apollo.canbus.Ge3.scu_3_303', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_bcm_304', full_name='apollo.canbus.Ge3.scu_bcm_304', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_bcs_1_306', full_name='apollo.canbus.Ge3.scu_bcs_1_306', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_bcs_2_307', full_name='apollo.canbus.Ge3.scu_bcs_2_307', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_epb_310', full_name='apollo.canbus.Ge3.scu_epb_310', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_vcu_1_312', full_name='apollo.canbus.Ge3.scu_vcu_1_312', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scu_eps_311', full_name='apollo.canbus.Ge3.scu_eps_311', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12697,
  serialized_end=13484,
)

_PC_BCM_201.fields_by_name['pc_reverselampreq'].enum_type = _PC_BCM_201_PC_REVERSELAMPREQTYPE
_PC_BCM_201.fields_by_name['pc_lowbeamreq'].enum_type = _PC_BCM_201_PC_LOWBEAMREQTYPE
_PC_BCM_201.fields_by_name['pc_highbeamreq'].enum_type = _PC_BCM_201_PC_HIGHBEAMREQTYPE
_PC_BCM_201.fields_by_name['pc_rightturnlampreq'].enum_type = _PC_BCM_201_PC_RIGHTTURNLAMPREQTYPE
_PC_BCM_201.fields_by_name['pc_leftturnlampreq'].enum_type = _PC_BCM_201_PC_LEFTTURNLAMPREQTYPE
_PC_BCM_201.fields_by_name['pc_hornreq'].enum_type = _PC_BCM_201_PC_HORNREQTYPE
_PC_BCM_201.fields_by_name['pc_hazardlampreq'].enum_type = _PC_BCM_201_PC_HAZARDLAMPREQTYPE
_PC_BCM_201_PC_REVERSELAMPREQTYPE.containing_type = _PC_BCM_201
_PC_BCM_201_PC_LOWBEAMREQTYPE.containing_type = _PC_BCM_201
_PC_BCM_201_PC_HIGHBEAMREQTYPE.containing_type = _PC_BCM_201
_PC_BCM_201_PC_RIGHTTURNLAMPREQTYPE.containing_type = _PC_BCM_201
_PC_BCM_201_PC_LEFTTURNLAMPREQTYPE.containing_type = _PC_BCM_201
_PC_BCM_201_PC_HORNREQTYPE.containing_type = _PC_BCM_201
_PC_BCM_201_PC_HAZARDLAMPREQTYPE.containing_type = _PC_BCM_201
_SCU_BCS_3_308.fields_by_name['bcs_rrwheelspdvd'].enum_type = _SCU_BCS_3_308_BCS_RRWHEELSPDVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_rrwheeldirectionvd'].enum_type = _SCU_BCS_3_308_BCS_RRWHEELDIRECTIONVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_rlwheelspdvd'].enum_type = _SCU_BCS_3_308_BCS_RLWHEELSPDVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_rlwheeldirectionvd'].enum_type = _SCU_BCS_3_308_BCS_RLWHEELDIRECTIONVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_frwheelspdvd'].enum_type = _SCU_BCS_3_308_BCS_FRWHEELSPDVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_frwheeldirectionvd'].enum_type = _SCU_BCS_3_308_BCS_FRWHEELDIRECTIONVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_flwheelspdvd'].enum_type = _SCU_BCS_3_308_BCS_FLWHEELSPDVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_flwheeldirectionvd'].enum_type = _SCU_BCS_3_308_BCS_FLWHEELDIRECTIONVDTYPE
_SCU_BCS_3_308.fields_by_name['bcs_rrwheeldirection'].enum_type = _SCU_BCS_3_308_BCS_RRWHEELDIRECTIONTYPE
_SCU_BCS_3_308.fields_by_name['bcs_rlwheeldirection'].enum_type = _SCU_BCS_3_308_BCS_RLWHEELDIRECTIONTYPE
_SCU_BCS_3_308.fields_by_name['bcs_frwheeldirection'].enum_type = _SCU_BCS_3_308_BCS_FRWHEELDIRECTIONTYPE
_SCU_BCS_3_308.fields_by_name['bcs_flwheeldirection'].enum_type = _SCU_BCS_3_308_BCS_FLWHEELDIRECTIONTYPE
_SCU_BCS_3_308_BCS_RRWHEELSPDVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_RRWHEELDIRECTIONVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_RLWHEELSPDVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_RLWHEELDIRECTIONVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_FRWHEELSPDVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_FRWHEELDIRECTIONVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_FLWHEELSPDVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_FLWHEELDIRECTIONVDTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_RRWHEELDIRECTIONTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_RLWHEELDIRECTIONTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_FRWHEELDIRECTIONTYPE.containing_type = _SCU_BCS_3_308
_SCU_BCS_3_308_BCS_FLWHEELDIRECTIONTYPE.containing_type = _SCU_BCS_3_308
_PC_EPB_203.fields_by_name['pc_epbreq'].enum_type = _PC_EPB_203_PC_EPBREQTYPE
_PC_EPB_203.fields_by_name['pc_epbenable'].enum_type = _PC_EPB_203_PC_EPBENABLETYPE
_PC_EPB_203_PC_EPBREQTYPE.containing_type = _PC_EPB_203
_PC_EPB_203_PC_EPBENABLETYPE.containing_type = _PC_EPB_203
_PC_BCS_202.fields_by_name['pc_brkpedenable'].enum_type = _PC_BCS_202_PC_BRKPEDENABLETYPE
_PC_BCS_202_PC_BRKPEDENABLETYPE.containing_type = _PC_BCS_202
_PC_VCU_205.fields_by_name['pc_accpedenable'].enum_type = _PC_VCU_205_PC_ACCPEDENABLETYPE
_PC_VCU_205.fields_by_name['pc_torqenable'].enum_type = _PC_VCU_205_PC_TORQENABLETYPE
_PC_VCU_205.fields_by_name['pc_gearreq'].enum_type = _PC_VCU_205_PC_GEARREQTYPE
_PC_VCU_205.fields_by_name['pc_gearenable'].enum_type = _PC_VCU_205_PC_GEARENABLETYPE
_PC_VCU_205_PC_ACCPEDENABLETYPE.containing_type = _PC_VCU_205
_PC_VCU_205_PC_TORQENABLETYPE.containing_type = _PC_VCU_205
_PC_VCU_205_PC_GEARREQTYPE.containing_type = _PC_VCU_205
_PC_VCU_205_PC_GEARENABLETYPE.containing_type = _PC_VCU_205
_PC_EPS_204.fields_by_name['pc_steerenable'].enum_type = _PC_EPS_204_PC_STEERENABLETYPE
_PC_EPS_204_PC_STEERENABLETYPE.containing_type = _PC_EPS_204
_SCU_1_301.fields_by_name['scu_stopbutst'].enum_type = _SCU_1_301_SCU_STOPBUTSTTYPE
_SCU_1_301.fields_by_name['scu_drvmode'].enum_type = _SCU_1_301_SCU_DRVMODETYPE
_SCU_1_301.fields_by_name['scu_faultst'].enum_type = _SCU_1_301_SCU_FAULTSTTYPE
_SCU_1_301_SCU_STOPBUTSTTYPE.containing_type = _SCU_1_301
_SCU_1_301_SCU_DRVMODETYPE.containing_type = _SCU_1_301
_SCU_1_301_SCU_FAULTSTTYPE.containing_type = _SCU_1_301
_SCU_BCM_304.fields_by_name['bcm_vehreversest'].enum_type = _SCU_BCM_304_BCM_VEHREVERSESTTYPE
_SCU_BCM_304.fields_by_name['bcm_rightturnlampst'].enum_type = _SCU_BCM_304_BCM_RIGHTTURNLAMPSTTYPE
_SCU_BCM_304.fields_by_name['bcm_rearfoglampst'].enum_type = _SCU_BCM_304_BCM_REARFOGLAMPSTTYPE
_SCU_BCM_304.fields_by_name['bcm_parkinglampst'].enum_type = _SCU_BCM_304_BCM_PARKINGLAMPSTTYPE
_SCU_BCM_304.fields_by_name['bcm_lowbeamst'].enum_type = _SCU_BCM_304_BCM_LOWBEAMSTTYPE
_SCU_BCM_304.fields_by_name['bcm_leftturnlampst'].enum_type = _SCU_BCM_304_BCM_LEFTTURNLAMPSTTYPE
_SCU_BCM_304.fields_by_name['bcm_keyst'].enum_type = _SCU_BCM_304_BCM_KEYSTTYPE
_SCU_BCM_304.fields_by_name['bcm_hornst'].enum_type = _SCU_BCM_304_BCM_HORNSTTYPE
_SCU_BCM_304.fields_by_name['bcm_highbeamst'].enum_type = _SCU_BCM_304_BCM_HIGHBEAMSTTYPE
_SCU_BCM_304.fields_by_name['bcm_hazardlampst'].enum_type = _SCU_BCM_304_BCM_HAZARDLAMPSTTYPE
_SCU_BCM_304.fields_by_name['bcm_frontfoglampst'].enum_type = _SCU_BCM_304_BCM_FRONTFOGLAMPSTTYPE
_SCU_BCM_304.fields_by_name['bcm_brakelightswitchst'].enum_type = _SCU_BCM_304_BCM_BRAKELIGHTSWITCHSTTYPE
_SCU_BCM_304_BCM_VEHREVERSESTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_RIGHTTURNLAMPSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_REARFOGLAMPSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_PARKINGLAMPSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_LOWBEAMSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_LEFTTURNLAMPSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_KEYSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_HORNSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_HIGHBEAMSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_HAZARDLAMPSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_FRONTFOGLAMPSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCM_304_BCM_BRAKELIGHTSWITCHSTTYPE.containing_type = _SCU_BCM_304
_SCU_BCS_1_306.fields_by_name['bcs_aebavailable'].enum_type = _SCU_BCS_1_306_BCS_AEBAVAILABLETYPE
_SCU_BCS_1_306.fields_by_name['bcs_cddavailable'].enum_type = _SCU_BCS_1_306_BCS_CDDAVAILABLETYPE
_SCU_BCS_1_306.fields_by_name['bcs_intidx'].enum_type = _SCU_BCS_1_306_BCS_INTIDXTYPE
_SCU_BCS_1_306.fields_by_name['bcs_vdcfaultst'].enum_type = _SCU_BCS_1_306_BCS_VDCFAULTSTTYPE
_SCU_BCS_1_306.fields_by_name['bcs_vdcactivest'].enum_type = _SCU_BCS_1_306_BCS_VDCACTIVESTTYPE
_SCU_BCS_1_306.fields_by_name['bcs_absfaultst'].enum_type = _SCU_BCS_1_306_BCS_ABSFAULTSTTYPE
_SCU_BCS_1_306.fields_by_name['bcs_absactivest'].enum_type = _SCU_BCS_1_306_BCS_ABSACTIVESTTYPE
_SCU_BCS_1_306.fields_by_name['bcs_faultst'].enum_type = _SCU_BCS_1_306_BCS_FAULTSTTYPE
_SCU_BCS_1_306.fields_by_name['bcs_drvmode'].enum_type = _SCU_BCS_1_306_BCS_DRVMODETYPE
_SCU_BCS_1_306_BCS_AEBAVAILABLETYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_CDDAVAILABLETYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_INTIDXTYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_VDCFAULTSTTYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_VDCACTIVESTTYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_ABSFAULTSTTYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_ABSACTIVESTTYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_FAULTSTTYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_1_306_BCS_DRVMODETYPE.containing_type = _SCU_BCS_1_306
_SCU_BCS_2_307.fields_by_name['bcs_vehspdvd'].enum_type = _SCU_BCS_2_307_BCS_VEHSPDVDTYPE
_SCU_BCS_2_307_BCS_VEHSPDVDTYPE.containing_type = _SCU_BCS_2_307
_SCU_EPB_310.fields_by_name['epb_intidx'].enum_type = _SCU_EPB_310_EPB_INTIDXTYPE
_SCU_EPB_310.fields_by_name['epb_drvmode'].enum_type = _SCU_EPB_310_EPB_DRVMODETYPE
_SCU_EPB_310.fields_by_name['epb_sysst'].enum_type = _SCU_EPB_310_EPB_SYSSTTYPE
_SCU_EPB_310.fields_by_name['epb_faultst'].enum_type = _SCU_EPB_310_EPB_FAULTSTTYPE
_SCU_EPB_310_EPB_INTIDXTYPE.containing_type = _SCU_EPB_310
_SCU_EPB_310_EPB_DRVMODETYPE.containing_type = _SCU_EPB_310
_SCU_EPB_310_EPB_SYSSTTYPE.containing_type = _SCU_EPB_310
_SCU_EPB_310_EPB_FAULTSTTYPE.containing_type = _SCU_EPB_310
_SCU_VCU_1_312.fields_by_name['vcu_elcsysfault'].enum_type = _SCU_VCU_1_312_VCU_ELCSYSFAULTTYPE
_SCU_VCU_1_312.fields_by_name['vcu_brkpedst'].enum_type = _SCU_VCU_1_312_VCU_BRKPEDSTTYPE
_SCU_VCU_1_312.fields_by_name['vcu_intidx'].enum_type = _SCU_VCU_1_312_VCU_INTIDXTYPE
_SCU_VCU_1_312.fields_by_name['vcu_gearintidx'].enum_type = _SCU_VCU_1_312_VCU_GEARINTIDXTYPE
_SCU_VCU_1_312.fields_by_name['vcu_geardrvmode'].enum_type = _SCU_VCU_1_312_VCU_GEARDRVMODETYPE
_SCU_VCU_1_312.fields_by_name['vcu_vehrdyst'].enum_type = _SCU_VCU_1_312_VCU_VEHRDYSTTYPE
_SCU_VCU_1_312.fields_by_name['vcu_faultst'].enum_type = _SCU_VCU_1_312_VCU_FAULTSTTYPE
_SCU_VCU_1_312.fields_by_name['vcu_drvmode'].enum_type = _SCU_VCU_1_312_VCU_DRVMODETYPE
_SCU_VCU_1_312.fields_by_name['vcu_gearpst'].enum_type = _SCU_VCU_1_312_VCU_GEARPSTTYPE
_SCU_VCU_1_312.fields_by_name['vcu_gearfaultst'].enum_type = _SCU_VCU_1_312_VCU_GEARFAULTSTTYPE
_SCU_VCU_1_312.fields_by_name['vcu_gearact'].enum_type = _SCU_VCU_1_312_VCU_GEARACTTYPE
_SCU_VCU_1_312_VCU_ELCSYSFAULTTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_BRKPEDSTTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_INTIDXTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_GEARINTIDXTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_GEARDRVMODETYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_VEHRDYSTTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_FAULTSTTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_DRVMODETYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_GEARPSTTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_GEARFAULTSTTYPE.containing_type = _SCU_VCU_1_312
_SCU_VCU_1_312_VCU_GEARACTTYPE.containing_type = _SCU_VCU_1_312
_SCU_EPS_311.fields_by_name['eps_intidx'].enum_type = _SCU_EPS_311_EPS_INTIDXTYPE
_SCU_EPS_311.fields_by_name['eps_faultst'].enum_type = _SCU_EPS_311_EPS_FAULTSTTYPE
_SCU_EPS_311.fields_by_name['eps_drvmode'].enum_type = _SCU_EPS_311_EPS_DRVMODETYPE
_SCU_EPS_311_EPS_INTIDXTYPE.containing_type = _SCU_EPS_311
_SCU_EPS_311_EPS_FAULTSTTYPE.containing_type = _SCU_EPS_311
_SCU_EPS_311_EPS_DRVMODETYPE.containing_type = _SCU_EPS_311
_GE3.fields_by_name['pc_bcm_201'].message_type = _PC_BCM_201
_GE3.fields_by_name['scu_bcs_3_308'].message_type = _SCU_BCS_3_308
_GE3.fields_by_name['pc_epb_203'].message_type = _PC_EPB_203
_GE3.fields_by_name['pc_bcs_202'].message_type = _PC_BCS_202
_GE3.fields_by_name['pc_vcu_205'].message_type = _PC_VCU_205
_GE3.fields_by_name['pc_eps_204'].message_type = _PC_EPS_204
_GE3.fields_by_name['scu_vcu_2_313'].message_type = _SCU_VCU_2_313
_GE3.fields_by_name['scu_1_301'].message_type = _SCU_1_301
_GE3.fields_by_name['scu_2_302'].message_type = _SCU_2_302
_GE3.fields_by_name['scu_3_303'].message_type = _SCU_3_303
_GE3.fields_by_name['scu_bcm_304'].message_type = _SCU_BCM_304
_GE3.fields_by_name['scu_bcs_1_306'].message_type = _SCU_BCS_1_306
_GE3.fields_by_name['scu_bcs_2_307'].message_type = _SCU_BCS_2_307
_GE3.fields_by_name['scu_epb_310'].message_type = _SCU_EPB_310
_GE3.fields_by_name['scu_vcu_1_312'].message_type = _SCU_VCU_1_312
_GE3.fields_by_name['scu_eps_311'].message_type = _SCU_EPS_311
DESCRIPTOR.message_types_by_name['Pc_bcm_201'] = _PC_BCM_201
DESCRIPTOR.message_types_by_name['Scu_bcs_3_308'] = _SCU_BCS_3_308
DESCRIPTOR.message_types_by_name['Pc_epb_203'] = _PC_EPB_203
DESCRIPTOR.message_types_by_name['Pc_bcs_202'] = _PC_BCS_202
DESCRIPTOR.message_types_by_name['Pc_vcu_205'] = _PC_VCU_205
DESCRIPTOR.message_types_by_name['Pc_eps_204'] = _PC_EPS_204
DESCRIPTOR.message_types_by_name['Scu_vcu_2_313'] = _SCU_VCU_2_313
DESCRIPTOR.message_types_by_name['Scu_1_301'] = _SCU_1_301
DESCRIPTOR.message_types_by_name['Scu_2_302'] = _SCU_2_302
DESCRIPTOR.message_types_by_name['Scu_3_303'] = _SCU_3_303
DESCRIPTOR.message_types_by_name['Scu_bcm_304'] = _SCU_BCM_304
DESCRIPTOR.message_types_by_name['Scu_bcs_1_306'] = _SCU_BCS_1_306
DESCRIPTOR.message_types_by_name['Scu_bcs_2_307'] = _SCU_BCS_2_307
DESCRIPTOR.message_types_by_name['Scu_epb_310'] = _SCU_EPB_310
DESCRIPTOR.message_types_by_name['Scu_vcu_1_312'] = _SCU_VCU_1_312
DESCRIPTOR.message_types_by_name['Scu_eps_311'] = _SCU_EPS_311
DESCRIPTOR.message_types_by_name['Ge3'] = _GE3
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pc_bcm_201 = _reflection.GeneratedProtocolMessageType('Pc_bcm_201', (_message.Message,), {
  'DESCRIPTOR' : _PC_BCM_201,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Pc_bcm_201)
  })
_sym_db.RegisterMessage(Pc_bcm_201)

Scu_bcs_3_308 = _reflection.GeneratedProtocolMessageType('Scu_bcs_3_308', (_message.Message,), {
  'DESCRIPTOR' : _SCU_BCS_3_308,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_bcs_3_308)
  })
_sym_db.RegisterMessage(Scu_bcs_3_308)

Pc_epb_203 = _reflection.GeneratedProtocolMessageType('Pc_epb_203', (_message.Message,), {
  'DESCRIPTOR' : _PC_EPB_203,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Pc_epb_203)
  })
_sym_db.RegisterMessage(Pc_epb_203)

Pc_bcs_202 = _reflection.GeneratedProtocolMessageType('Pc_bcs_202', (_message.Message,), {
  'DESCRIPTOR' : _PC_BCS_202,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Pc_bcs_202)
  })
_sym_db.RegisterMessage(Pc_bcs_202)

Pc_vcu_205 = _reflection.GeneratedProtocolMessageType('Pc_vcu_205', (_message.Message,), {
  'DESCRIPTOR' : _PC_VCU_205,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Pc_vcu_205)
  })
_sym_db.RegisterMessage(Pc_vcu_205)

Pc_eps_204 = _reflection.GeneratedProtocolMessageType('Pc_eps_204', (_message.Message,), {
  'DESCRIPTOR' : _PC_EPS_204,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Pc_eps_204)
  })
_sym_db.RegisterMessage(Pc_eps_204)

Scu_vcu_2_313 = _reflection.GeneratedProtocolMessageType('Scu_vcu_2_313', (_message.Message,), {
  'DESCRIPTOR' : _SCU_VCU_2_313,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_vcu_2_313)
  })
_sym_db.RegisterMessage(Scu_vcu_2_313)

Scu_1_301 = _reflection.GeneratedProtocolMessageType('Scu_1_301', (_message.Message,), {
  'DESCRIPTOR' : _SCU_1_301,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_1_301)
  })
_sym_db.RegisterMessage(Scu_1_301)

Scu_2_302 = _reflection.GeneratedProtocolMessageType('Scu_2_302', (_message.Message,), {
  'DESCRIPTOR' : _SCU_2_302,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_2_302)
  })
_sym_db.RegisterMessage(Scu_2_302)

Scu_3_303 = _reflection.GeneratedProtocolMessageType('Scu_3_303', (_message.Message,), {
  'DESCRIPTOR' : _SCU_3_303,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_3_303)
  })
_sym_db.RegisterMessage(Scu_3_303)

Scu_bcm_304 = _reflection.GeneratedProtocolMessageType('Scu_bcm_304', (_message.Message,), {
  'DESCRIPTOR' : _SCU_BCM_304,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_bcm_304)
  })
_sym_db.RegisterMessage(Scu_bcm_304)

Scu_bcs_1_306 = _reflection.GeneratedProtocolMessageType('Scu_bcs_1_306', (_message.Message,), {
  'DESCRIPTOR' : _SCU_BCS_1_306,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_bcs_1_306)
  })
_sym_db.RegisterMessage(Scu_bcs_1_306)

Scu_bcs_2_307 = _reflection.GeneratedProtocolMessageType('Scu_bcs_2_307', (_message.Message,), {
  'DESCRIPTOR' : _SCU_BCS_2_307,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_bcs_2_307)
  })
_sym_db.RegisterMessage(Scu_bcs_2_307)

Scu_epb_310 = _reflection.GeneratedProtocolMessageType('Scu_epb_310', (_message.Message,), {
  'DESCRIPTOR' : _SCU_EPB_310,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_epb_310)
  })
_sym_db.RegisterMessage(Scu_epb_310)

Scu_vcu_1_312 = _reflection.GeneratedProtocolMessageType('Scu_vcu_1_312', (_message.Message,), {
  'DESCRIPTOR' : _SCU_VCU_1_312,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_vcu_1_312)
  })
_sym_db.RegisterMessage(Scu_vcu_1_312)

Scu_eps_311 = _reflection.GeneratedProtocolMessageType('Scu_eps_311', (_message.Message,), {
  'DESCRIPTOR' : _SCU_EPS_311,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Scu_eps_311)
  })
_sym_db.RegisterMessage(Scu_eps_311)

Ge3 = _reflection.GeneratedProtocolMessageType('Ge3', (_message.Message,), {
  'DESCRIPTOR' : _GE3,
  '__module__' : 'modules.canbus.proto.ge3_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.Ge3)
  })
_sym_db.RegisterMessage(Ge3)


# @@protoc_insertion_point(module_scope)
